(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    240561,       5916]
NotebookOptionsPosition[    236744,       5835]
NotebookOutlinePosition[    237255,       5854]
CellTagsIndexPosition[    237212,       5851]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "General Comments:",
 StyleBox["\nChange the n and l values below to produce the relevant \
calculations and plots.\nThe program may require you to evaluate it a few \
times in a row to run properly because of some issues with Mathematica.\nThe \
quantum plots are only the down transitions as of now (up transitions \
essentially are small enough not to effect the sum), but I commented out an \
attempt to do the up transitions in a cell below.\nThe header describes what \
each cell block does, and if needed it should be easy to edit how a graph \
looks in the ListPlot lines.", "CodeText"]
}], "Text",
 CellChangeTimes->{{3.900152116279749*^9, 3.900152292975897*^9}, {
  3.9001523342884984`*^9, 3.9001523345484285`*^9}, {3.900163992824816*^9, 
  3.900164069026273*^9}, {3.9001648949840117`*^9, 
  3.9001648970530605`*^9}},ExpressionUUID->"2eeb7966-7325-4277-82ec-\
f07e61611c61"],

Cell[CellGroupData[{

Cell["Specify State", "Section",
 CellChangeTimes->{{3.9000633588067493`*^9, 3.9000634787733603`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"6f565e33-5adc-44d5-803b-4ad0513aada9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"l", "=", "50"}], ";"}]}], "Input",
 CellChangeTimes->{{3.897136297131663*^9, 3.8971362999030256`*^9}, {
   3.8971521637082624`*^9, 3.8971521712167835`*^9}, {3.897152334708086*^9, 
   3.8971523436653223`*^9}, {3.8971528000208187`*^9, 3.8971528041809483`*^9}, 
   3.8973853252110047`*^9, {3.8973860711906495`*^9, 3.8973860762626553`*^9}, {
   3.8993850487076797`*^9, 3.8993850639786005`*^9}, {3.900063140632578*^9, 
   3.9000631414981656`*^9}, {3.9000631903967757`*^9, 3.900063203072787*^9}, {
   3.9000632448023157`*^9, 3.9000632455519185`*^9}, {3.900063276216487*^9, 
   3.9000632763405747`*^9}, {3.9000633172448115`*^9, 
   3.9000633489680433`*^9}, {3.900064223061701*^9, 3.900064228705768*^9}, {
   3.9000667541227045`*^9, 3.9000667546225095`*^9}, {3.900078416525633*^9, 
   3.900078416834056*^9}, {3.9000819375457563`*^9, 3.900081937805732*^9}, {
   3.9001490732647038`*^9, 3.9001490735145755`*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[289]:=",ExpressionUUID->"6a4c7154-a70f-437d-80a3-9c67b2576039"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define Constants", "Section",
 CellChangeTimes->{{3.9000634847528086`*^9, 3.9000634865959597`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"f72f3a1d-79af-4971-a123-483d5eac55c8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{"1.60218", "*", 
    RowBox[{"10", "^", 
     RowBox[{"-", "19"}]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Electon", " ", "Charge"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"9.10938", "*", 
    RowBox[{"10", "^", 
     RowBox[{"-", "31"}]}]}]}], 
  RowBox[{"(*", 
   RowBox[{"Electron", " ", "Mass"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Epsilon]", "0"], "=", 
   RowBox[{"8.8542", "*", 
    RowBox[{"10", "^", 
     RowBox[{"-", "12"}]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Vacuum", " ", "Permittivity"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"2.998", "*", 
    RowBox[{"10", "^", "8"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Speed", " ", "of", " ", "Light"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{"6.62607", "*", 
    RowBox[{"10", "^", 
     RowBox[{"-", "34"}]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Planck", " ", "Constant"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[HBar]", "=", 
   RowBox[{"h", "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Reduced", " ", "Planck", " ", "Constant"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["a", "0"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4", "\[Pi]", "*", 
      SubscriptBox["\[Epsilon]", "0"], "*", 
      RowBox[{"\[HBar]", "^", "2"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"m", "*", 
      RowBox[{"e", "^", "2"}]}], ")"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Bohr", " ", "Radius"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["v", "0"], "=", 
   RowBox[{
    RowBox[{"e", "^", "2"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", "\[Pi]", "*", 
      SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]"}], ")"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Velocity", " ", "at", " ", "Bohr", " ", "Radius"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{"m", "*", 
    RowBox[{
     RowBox[{"e", "^", "4"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "\[Pi]", "*", 
          SubscriptBox["\[Epsilon]", "0"]}], ")"}], "^", "2"}], "*", 
       RowBox[{"\[HBar]", "^", "2"}]}], ")"}]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Rydberg", " ", "Constant"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ry", "=", 
   RowBox[{"m", "*", 
    RowBox[{
     RowBox[{"e", "^", "4"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "\[Pi]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "\[Pi]", "*", 
          SubscriptBox["\[Epsilon]", "0"]}], ")"}], "^", "2"}], "*", 
       RowBox[{"\[HBar]", "^", "3"}]}], ")"}]}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Rydberg", " ", "Frequency"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"e", "^", "2"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", "*", "\[Pi]", "*", 
      SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", "c"}], ")"}]}]}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"fine", " ", "structure", " ", "constant"}], "*)"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{
    RowBox[{"n", "^", "2"}], "*", 
    SubscriptBox["a", "0"]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Semimajor", " ", "Axis"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", 
   RowBox[{"n", "*", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"l", 
      RowBox[{"(", 
       RowBox[{"l", "+", "1"}], ")"}]}], "]"}], "*", 
    SubscriptBox["a", "0"]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"Semiminor", " ", "Axis"}], "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "/", 
      RowBox[{"a", "^", "2"}]}]}], "]"}]}], " ", 
  RowBox[{"(*", "Eccentricity", "*)"}], ";"}]}], "Input",
 CellChangeTimes->{{3.9000631039354515`*^9, 3.900063129884411*^9}, {
   3.900063861876479*^9, 3.9000638626160135`*^9}, {3.9000662151971807`*^9, 
   3.900066295780759*^9}, {3.9000676415013676`*^9, 3.900067645213624*^9}, 
   3.900074127521474*^9, {3.900074158841234*^9, 3.9000741767934637`*^9}, {
   3.9000817407667537`*^9, 3.9000817522710896`*^9}, {3.9000818474769697`*^9, 
   3.9000818807527623`*^9}, {3.9001491446557293`*^9, 3.9001491450655227`*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[291]:=",ExpressionUUID->"af1cb04f-d80b-4735-b1fd-688a1a44cd7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Power Quantum Approach", "Section",
 CellChangeTimes->{{3.9000634950706735`*^9, 3.900063498871943*^9}, {
  3.9000636478787875`*^9, 3.9000636535923214`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"ca0149b0-55db-4ca7-9825-795dbcc37b31"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dif", "[", 
     RowBox[{"n_", ",", " ", "n\[Prime]_", ",", " ", "l_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", " ", 
     RowBox[{
      RowBox[{"n\[Prime]", " ", "==", "n"}], ",", " ", 
      RowBox[{
       RowBox[{"output", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.5", "*", "n", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"n", "^", "2"}], " ", "-", " ", 
              RowBox[{"l", "^", "2"}]}], ")"}], "^", 
            RowBox[{"(", "0.5", ")"}]}]}], ")"}], "^", 
         RowBox[{"(", "2", ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"IntegerPart", "[", "output", "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"output", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{"4", "*", 
             RowBox[{"Factorial", "[", 
              RowBox[{
               RowBox[{"2", "*", "l"}], "-", "1"}], "]"}]}], ")"}]], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"Factorial", "[", 
             RowBox[{"n", "+", "l"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Factorial", "[", 
               RowBox[{"n\[Prime]", "+", "l", "-", "1"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Factorial", "[", 
                 RowBox[{"n", "-", "l", "-", "1"}], "]"}], "*", 
                RowBox[{"Factorial", "[", 
                 RowBox[{"n\[Prime]", "-", "l"}], "]"}]}], ")"}]}], ")"}]}], 
           "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"n", "+", "n\[Prime]", "-", 
                 RowBox[{"2", "*", "l"}], "-", "2"}], ")"}]}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "*", "n", "*", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"l", "+", "1"}], ")"}]}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "+", "n\[Prime]"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"n", "+", "n\[Prime]"}], ")"}]}]}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Hypergeometric2F1", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], ",", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
              RowBox[{"2", "*", "l"}], ",", 
              FractionBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], "]"}],
             "-", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"n", "+", "n\[Prime]"}], ")"}]], ")"}], "^", "2"}], 
             "*", 
             RowBox[{"Hypergeometric2F1", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], "-", "2"}], ",", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
               RowBox[{"2", "*", "l"}], ",", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
              "]"}]}]}], ")"}]}], ")"}], "^", "2"}]}]}], "]"}]}], ";"}], "  ",
   "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Dipole", " ", "Moment", " ", "Function"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getOmega", "[", 
     RowBox[{"n_", ",", "n\[Prime]_"}], "]"}], "=", 
    RowBox[{"N", "[", 
     RowBox[{"R", "*", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "1"}], 
          RowBox[{"(", 
           RowBox[{"n", "^", "2"}], ")"}]], "-", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"-", "1"}], 
           RowBox[{"(", 
            RowBox[{"n\[Prime]", "^", "2"}], ")"}]], ")"}]}], ")"}], 
       "\[HBar]"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Function", " ", "to", " ", "get", " ", "angular", " ", "momentum", " ", 
    "from", " ", "quantum", " ", "state"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"powerQuantumApproach", "[", 
     RowBox[{
     "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
      "l\[Prime]_"}], "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"\[HBar]", "*", 
        RowBox[{"\[Omega]", "^", "4"}], "*", 
        RowBox[{"Max", "[", 
         RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"3", 
        RowBox[{"\[Pi]", "^", "3"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l"}], "+", "1"}], ")"}], "*", 
        RowBox[{"Ry", "^", "3"}]}], ")"}]], "*", 
     RowBox[{"dif", "[", 
      RowBox[{"n", ",", "n\[Prime]", ",", "l"}], "]"}], "*", 
     RowBox[{"10", "^", "9"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Power", " ", "formula", " ", "in", " ", "quantum", " ", "approach", " ", 
    RowBox[{"pg", ".", " ", "47"}], " ", "Jasper"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"powerQuantumData", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"getOmega", "[", 
         RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
        RowBox[{"powerQuantumApproach", "[", 
         RowBox[{
          RowBox[{"getOmega", "[", 
           RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", "n\[Prime]",
           ",", "l", ",", 
          RowBox[{"l", "-", "1"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n\[Prime]", ",", "l", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plot", " ", "a", " ", "table", " ", "of", " ", "n"}], ",", " ", 
    "n\[Prime]", ",", " ", "\[Omega]", ",", " ", "Power"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"powerQuantumData", ",", 
    RowBox[{"AxesLabel", "->", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
       "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
    RowBox[{"PlotLabel", " ", "->", 
     RowBox[{"Style", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
        "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}], 
        "[", 
        RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
    RowBox[{"PlotRange", "->", "All"}]}], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Graph", " ", "\[Omega]", " ", "vs", " ", "Power"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Here", " ", "is", " ", "a", " ", "possible", " ", "approach", " ", "to", 
     " ", "plot", " ", "the", " ", "up", " ", "quantum", " ", 
     RowBox[{"transitions", ".", " ", "It"}], " ", "looks", " ", "like", " ", 
     "it", " ", "matches", " ", 
     RowBox[{"Pavel", "'"}], "s", " ", 
     RowBox[{"results", ".", " ", "The"}], " ", "up", " ", "transitions", " ",
      "are", " ", "much", " ", 
     RowBox[{"smaller", ".", " ", "The"}], " ", "code", " ", "is", " ", "a", 
     " ", "little", " ", "complicated", " ", "because"}], ",", " ", 
    RowBox[{"for", " ", "one"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"different", " ", 
       RowBox[{"n", "'"}], " ", "values", " ", "have", " ", "to", " ", "be", 
       " ", 
       RowBox[{
       "used", ".", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"dif", "[", 
         RowBox[{"n_", ",", " ", "n\[Prime]_", ",", " ", "l_"}], "]"}]}]}], ":=",
       "\[IndentingNewLine]", 
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{"n\[Prime]", " ", "==", "n"}], ",", " ", 
        RowBox[{
         RowBox[{"output", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1.5", "*", "n", "*", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"n", "^", "2"}], " ", "-", " ", 
                RowBox[{"l", "^", "2"}]}], ")"}], "^", 
              RowBox[{"(", "0.5", ")"}]}]}], ")"}], "^", 
           RowBox[{"(", "2", ")"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"IntegerPart", "[", "output", "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"output", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], 
             RowBox[{"(", 
              RowBox[{"4", "*", 
               RowBox[{"Factorial", "[", 
                RowBox[{
                 RowBox[{"2", "*", "l"}], "-", "1"}], "]"}]}], ")"}]], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"Factorial", "[", 
               RowBox[{"n", "+", "l"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Factorial", "[", 
                 RowBox[{"n\[Prime]", "+", "l", "-", "1"}], "]"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Factorial", "[", 
                   RowBox[{"n", "-", "l", "-", "1"}], "]"}], "*", 
                  RowBox[{"Factorial", "[", 
                   RowBox[{"n\[Prime]", "-", "l"}], "]"}]}], ")"}]}], ")"}]}],
              "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "n\[Prime]", "-", 
                   RowBox[{"2", "*", "l"}], "-", "2"}], ")"}]}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "*", "n", "*", "n\[Prime]"}], ")"}], "^", 
                 RowBox[{"(", 
                  RowBox[{"l", "+", "1"}], ")"}]}]}], ")"}], "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "+", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"n", "+", "n\[Prime]"}], ")"}]}]}], ")"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Hypergeometric2F1", "[", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], ",", 
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
                RowBox[{"2", "*", "l"}], ",", 
                FractionBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
               "]"}], "-", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 FractionBox[
                  RowBox[{"(", 
                   RowBox[{"n", "-", "n\[Prime]"}], ")"}], 
                  RowBox[{"(", 
                   RowBox[{"n", "+", "n\[Prime]"}], ")"}]], ")"}], "^", "2"}],
                "*", 
               RowBox[{"Hypergeometric2F1", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], "-", "2"}], 
                 ",", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
                 RowBox[{"2", "*", "l"}], ",", 
                 FractionBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
                "]"}]}]}], ")"}]}], ")"}], "^", "2"}]}]}], "]"}]}], ";", "  ",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"getOmega", "[", 
       RowBox[{"n_", ",", "n\[Prime]_"}], "]"}], "=", 
      RowBox[{"N", "[", 
       RowBox[{"R", "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n", "^", "2"}], ")"}]], "-", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"-", "1"}], 
             RowBox[{"(", 
              RowBox[{"n\[Prime]", "^", "2"}], ")"}]], ")"}]}], ")"}], 
         "\[HBar]"]}], "]"}]}], ";", "\n", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"powerQuantumApproachUp", "[", 
       RowBox[{
       "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
        "l\[Prime]_"}], "]"}], "=", 
      RowBox[{
       FractionBox[
        RowBox[{"(", 
         RowBox[{"\[HBar]", "*", 
          RowBox[{"\[Omega]", "^", "4"}], "*", 
          RowBox[{"Max", "[", 
           RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"3", 
          RowBox[{"\[Pi]", "^", "3"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "l"}], "+", "1"}], ")"}], "*", 
          RowBox[{"Ry", "^", "3"}]}], ")"}]], "*", 
       RowBox[{"dif", "[", 
        RowBox[{"n\[Prime]", ",", "n", ",", 
         RowBox[{"l", "+", "1"}]}], "]"}], "*", 
       RowBox[{"10", "^", "9"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Power", " ", "formula", " ", "with", " ", "different", " ", "values", 
       " ", "for", " ", "dipole", " ", "calculation", " ", "for", " ", "up", 
       " ", "transition"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"powerQuantumData", "=", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"getOmega", "[", 
            RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
           RowBox[{"powerQuantumApproachUp", "[", 
            RowBox[{
             RowBox[{"getOmega", "[", 
              RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", 
             "n\[Prime]", ",", "l", ",", 
             RowBox[{"l", "+", "1"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n\[Prime]", ",", 
           RowBox[{"l", "+", "2"}], ",", 
           RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "Plot", " ", "a", " ", "table", " ", "with", " ", "some", " ", 
          "modifications", " ", "such", " ", "as", " ", "so", " ", 
          RowBox[{"n", "'"}], " ", "does", " ", "not", " ", "go", " ", 
          "below", " ", "l"}], "+", "2"}], "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"ListPlot", "[", 
        RowBox[{"powerQuantumData", ",", 
         RowBox[{"AxesLabel", "->", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", 
            " ", "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
         RowBox[{"PlotLabel", " ", "->", 
          RowBox[{"Style", "[", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
             "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", 
              "]"}], "[", 
             RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
         RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}]}]}], 
   "\[IndentingNewLine]", "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.900063689396012*^9, 3.900063692430037*^9}, {
   3.900066723589699*^9, 3.900066747298916*^9}, {3.9000668587541575`*^9, 
   3.900066894106936*^9}, {3.9000673160409107`*^9, 3.900067321442143*^9}, {
   3.900075979593145*^9, 3.900075983883935*^9}, {3.9000774807169313`*^9, 
   3.9000774822531605`*^9}, {3.900077579319106*^9, 3.900077683919129*^9}, {
   3.9000778526781483`*^9, 3.900077855246292*^9}, {3.900077906267125*^9, 
   3.9000779072866306`*^9}, 3.900078307983844*^9, {3.900149096713628*^9, 
   3.900149123252035*^9}, {3.900149556761611*^9, 3.9001496419293547`*^9}, {
   3.900150083698333*^9, 3.9001501495211673`*^9}, {3.9001503649956055`*^9, 
   3.900150393580615*^9}, {3.9001504390270176`*^9, 3.9001504452817636`*^9}, {
   3.900155236668771*^9, 3.90015527377295*^9}, {3.900156345885929*^9, 
   3.9001563511245584`*^9}, {3.9001638826389008`*^9, 3.900163985793487*^9}, {
   3.9001645064275565`*^9, 3.9001646900357723`*^9}, {3.900164721934119*^9, 
   3.9001647844766855`*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[404]:=",ExpressionUUID->"ec8051a9-b286-4672-82db-371c45c552fb"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAzwXRk1qPlkJ1JxBD+eaBOWdhEspV
ZJVCVtj2TFgnvDmm/VSsZkqUQqZH/rzBQuc5lGxcRkZAk0KaSWRlTeEKOjsE
faHLRJJCluh115hmKDrpnsSG6FaRQnr4Wc9LiEI6MWbtp6Z1kEJJFs0VA4BY
OkXwnEFKQI9CY1/fk6/0bDqPVWKKLKuNQtems9skMX86KyKMYXsqjEJv5Pko
DxOPOgi79yDdvIpCvRr65Uj0nDqDU4M7FGGJQhXZX2u2dak6f2yiivwViELA
7h4Nxke1OhzkCuiI2oZC9LDL7zoCwTqU2woKwa2FQism5/L1IMo6MZVjmr+O
hEKtl8/UIF7TOgBln4CwfINCUE+vk5bO2zpwA8lZz3aCQt6Ytag5ZOM6jLY3
GGZ8gULZEABzoFfqOiVp08bLjIBCWnnWhHx38TrVApXXxk5/QgTKvEVQqPY6
3t1pDjaXfUKUErO4ksz8OndbH1XV8XtC/AxFbzb2ATvDGblMp116QsRc62Ry
BAY7aUULl7/ZeEI5/46Ji40KO6fD2HxBZXdCUSOrBtuJDztAoJazXv91QiDa
gIG0dhI7U5mQP1andEKjogh5+lMVO0J8im9zXHNCvluGA5BSGDsH003vDB5y
QtTOXDBbZhs7WsTc7oPrcEKfbhFBiYEeOwrXhriGiG9Csd+SgWXKIDtuA3Nc
fk9tQmBc4YrMRyI77QHwe+cqa0KRBI+yPrAjOyGlpF3KGWlCzVc/n6/6JDuE
w5LEPRtnQhxYVsfnHSY7Z27i7mUuZUKDx+KMqRAnO6hDQKlzUmNCTwKjX9TJ
Jzsnx/J0o4ZhQqJx5A+FQCg7Lx71fXmUX0J16mOZMmwoO2pFd00iOVxC+8gi
v8ZEKDvTr6il9/lYQo9lpM+xwic79aDPpcHVVUIHO6XE+N4mO9TYgBpZy1JC
9aUGizyTJTuILCbdTLNPQufqiFS42SM70o7gX0H/SULG2bfNMq0hOyqrPU2Z
eERCEht/MLMRHjsuiBHy7zo+QitSO1Pqzxc7Bv8Y0jHYM0Kw7wtIvIoQOw9H
W345iyNCGkzQc/5vADtyZnNV
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox[
     "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
      HoldForm], TraditionalForm], 
    FormBox[
     TagBox["\"Power (Watts)\"", HoldForm], TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
    StyleBox["\"Transition from n=100, l=50\"", 
     GrayLevel[0], StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 6.201238942785452*^12}, {0, 1.0100970086821574`*^-23}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.9000776637938166`*^9, 3.900077704566264*^9}, 
   3.900077908686577*^9, 3.9000780180856147`*^9, 3.9000781023069525`*^9, 
   3.9000781730117245`*^9, {3.900078325565708*^9, 3.900078351676276*^9}, 
   3.900081536358881*^9, {3.9000819100460043`*^9, 3.900081945987137*^9}, {
   3.900148945791415*^9, 3.900148957210967*^9}, {3.900149108751742*^9, 
   3.9001491246486316`*^9}, 3.900149206790079*^9, {3.9001495306584644`*^9, 
   3.9001496003095446`*^9}, 3.9001496449096766`*^9, {3.900150144383188*^9, 
   3.9001501500708714`*^9}, {3.9001503732574253`*^9, 
   3.9001503901375384`*^9}, {3.900150441639315*^9, 3.900150445713734*^9}, {
   3.900155253337247*^9, 3.9001552746045294`*^9}, 3.9001563530080705`*^9, {
   3.9001638921757503`*^9, 3.9001638947684803`*^9}, 3.900164081430609*^9, 
   3.9001641411151037`*^9, {3.900164573067581*^9, 3.9001646274956665`*^9}, 
   3.9001646632754574`*^9, {3.9001646997223477`*^9, 3.9001647467429905`*^9}, {
   3.9001647922123737`*^9, 3.9001648023102045`*^9}, 3.900164869618452*^9},
 CellLabel->
  "Out[408]=",ExpressionUUID->"c2cf7e42-226d-4534-93a5-6a8a0caace9a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Power Semi-Classical Approach", "Section",
 CellChangeTimes->{{3.9000635670394464`*^9, 3.9000635733173923`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"48efb0eb-5b55-4cc7-9dea-c52ef8164cce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "0"], "=", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", "^", "3"}], "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", "\[Pi]"}], ")"}], "^", "2"}], "*", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "0"], "^", "2"}], "*", 
           RowBox[{"\[HBar]", "^", "3"}]}], ")"}], 
         RowBox[{"m", "*", 
          RowBox[{"e", "^", "4"}]}]]}], ")"}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Find", " ", "Omega", " ", "Naught"}], "*)"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"maxK", "=", 
     FractionBox[
      RowBox[{"N", "[", 
       RowBox[{"R", "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n", "^", "2"}], ")"}]], "-", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"-", "1"}], 
             RowBox[{"(", 
              RowBox[{"l", "^", "2"}], ")"}]], ")"}]}], ")"}], "\[HBar]"]}], 
       "]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "find", " ", "maxK", " ", "that", " ", "fits", " ", "graph", " ", "so", 
     " ", "semi", " ", "classical", " ", "graph", " ", "fits", " ", "size"}], 
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"besselJPrime", "[", 
      RowBox[{"v_", ",", "z_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"BesselJ", "[", 
         RowBox[{
          RowBox[{"v", "-", "1"}], ",", "z"}], "]"}], "-", 
        RowBox[{"BesselJ", "[", 
         RowBox[{
          RowBox[{"v", "+", "1"}], ",", "z"}], "]"}]}], ")"}]}]}], " ", 
    RowBox[{"(*", 
     RowBox[{
     "First", " ", "Derivative", " ", "of", " ", "the", " ", "Bessel", " ", 
      "Function"}], "*)"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"powerSemiClassicalApproach", "[", 
      RowBox[{"k_", ",", "n_", ",", "l_"}], "]"}], "=", " ", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"e", "^", "2"}], 
        RowBox[{"3", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", 
         RowBox[{"c", "^", "3"}]}]], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "*", 
         SubscriptBox["\[Omega]", "0"]}], ")"}], "^", "4"}], "*", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"a", "^", "2"}], 
        RowBox[{"k", "^", "2"}]], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"besselJPrime", "[", 
          RowBox[{"k", ",", 
           RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "^", "2"}], " ", "+", 
        RowBox[{
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           SuperscriptBox["\[Epsilon]", "2"]], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"BesselJ", "[", 
            RowBox[{"k", ",", 
             RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}], "^", "2"}]}]}],
        ")"}]}]}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerSemiClassicalData", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k", "*", 
          SubscriptBox["\[Omega]", "0"]}], ",", 
         RowBox[{"powerSemiClassicalApproach", "[", 
          RowBox[{"k", ",", "n", ",", "l"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "maxK"}], "}"}]}], "]"}]}], ";"}], "\n", 
   "\n", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"powerSemiClassicalData", ",", 
     RowBox[{"AxesLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
        "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
     RowBox[{"PlotLabel", " ", "->", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
         "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}],
          "[", 
         RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.900063619787818*^9, 3.900063620350812*^9}, {
   3.900063772588191*^9, 3.9000637998820353`*^9}, 3.9000638789429655`*^9, {
   3.900066346845398*^9, 3.9000663474749947`*^9}, {3.900066445919257*^9, 
   3.9000664479081984`*^9}, {3.90006653036629*^9, 3.900066552400159*^9}, 
   3.9000674753207054`*^9, {3.900067515606459*^9, 3.9000675205859575`*^9}, {
   3.900075953221387*^9, 3.9000759694080105`*^9}, 3.900077962687995*^9, {
   3.9000780597574606`*^9, 3.900078068560458*^9}, 3.9000781180096464`*^9, 
   3.9000781627234025`*^9, {3.9000782275987225`*^9, 3.9000782286981287`*^9}, {
   3.9000783376960726`*^9, 3.9000783387854815`*^9}, {3.900078483936053*^9, 
   3.900078512405204*^9}, {3.9001492251371837`*^9, 3.900149242298252*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[398]:=",ExpressionUUID->"fb2cccf3-9b56-44e0-beb5-8dbda99d728e"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1lHk8VOsfx1FXI1nqZpDbgrquynJt6Tnl6mup3DRJYibZsidZsk/WMRTD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     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox[
     "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
      HoldForm], TraditionalForm], 
    FormBox[
     TagBox["\"Power (Watts)\"", HoldForm], TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
    StyleBox["\"Transition from n=100, l=50\"", 
     GrayLevel[0], StripOnInput -> False], TraditionalForm],
  PlotRange->{{0, 6.201238942785452*^12}, {0, 7.3511934199747*^-24}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.9000637223997974`*^9, 3.9000638010524387`*^9}, {
   3.9000638367865324`*^9, 3.900063879642576*^9}, {3.9000663434928207`*^9, 
   3.900066348607097*^9}, {3.9000665317155504`*^9, 3.900066549515002*^9}, {
   3.900067088602045*^9, 3.900067138361656*^9}, 3.9000672906678934`*^9, {
   3.9000674813804855`*^9, 3.900067521485566*^9}, {3.9000675716363096`*^9, 
   3.9000675866261935`*^9}, {3.900075965492906*^9, 3.9000759705673375`*^9}, 
   3.9000771246524596`*^9, {3.900077526973424*^9, 3.900077555287039*^9}, {
   3.9000779507471704`*^9, 3.9000779631393733`*^9}, 3.900078020358717*^9, {
   3.9000780699097385`*^9, 3.9000780946739254`*^9}, {3.9000781393937387`*^9, 
   3.900078164562422*^9}, {3.900078230945505*^9, 3.900078239360777*^9}, {
   3.900078334096576*^9, 3.9000783522959456`*^9}, 3.9000815366987*^9, {
   3.900081910385098*^9, 3.9000819461467104`*^9}, {3.9001489465010347`*^9, 
   3.9001489573709345`*^9}, {3.900149246002513*^9, 3.9001492633330345`*^9}, 
   3.900149530798441*^9, 3.900149661277607*^9, 3.900164081580479*^9, 
   3.9001641448065543`*^9, {3.900164792412317*^9, 3.9001648024600735`*^9}, 
   3.900164867008306*^9},
 Background->GrayLevel[0.85],
 CellLabel->
  "Out[403]=",ExpressionUUID->"75367643-d838-444f-bd0b-42faae7b97f3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quantum Power vs Semi-Classical Power", "Section",
 CellChangeTimes->{{3.9000640264380255`*^9, 3.900064037752824*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"94b7af9b-ca98-47d3-993e-1b729998020d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dif", "[", 
     RowBox[{"n_", ",", " ", "n\[Prime]_", ",", " ", "l_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", " ", 
     RowBox[{
      RowBox[{"n\[Prime]", " ", "==", "n"}], ",", " ", 
      RowBox[{
       RowBox[{"output", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.5", "*", "n", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"n", "^", "2"}], " ", "-", " ", 
              RowBox[{"l", "^", "2"}]}], ")"}], "^", 
            RowBox[{"(", "0.5", ")"}]}]}], ")"}], "^", 
         RowBox[{"(", "2", ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"IntegerPart", "[", "output", "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"output", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{"4", "*", 
             RowBox[{"Factorial", "[", 
              RowBox[{
               RowBox[{"2", "*", "l"}], "-", "1"}], "]"}]}], ")"}]], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"Factorial", "[", 
             RowBox[{"n", "+", "l"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Factorial", "[", 
               RowBox[{"n\[Prime]", "+", "l", "-", "1"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Factorial", "[", 
                 RowBox[{"n", "-", "l", "-", "1"}], "]"}], "*", 
                RowBox[{"Factorial", "[", 
                 RowBox[{"n\[Prime]", "-", "l"}], "]"}]}], ")"}]}], ")"}]}], 
           "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"n", "+", "n\[Prime]", "-", 
                 RowBox[{"2", "*", "l"}], "-", "2"}], ")"}]}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "*", "n", "*", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"l", "+", "1"}], ")"}]}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "+", "n\[Prime]"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"n", "+", "n\[Prime]"}], ")"}]}]}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Hypergeometric2F1", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], ",", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
              RowBox[{"2", "*", "l"}], ",", 
              FractionBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], "]"}],
             "-", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"n", "+", "n\[Prime]"}], ")"}]], ")"}], "^", "2"}], 
             "*", 
             RowBox[{"Hypergeometric2F1", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], "-", "2"}], ",", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
               RowBox[{"2", "*", "l"}], ",", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
              "]"}]}]}], ")"}]}], ")"}], "^", "2"}]}]}], "]"}]}], ";"}], "  ",
   "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Dipole", " ", "Moment", " ", "Function"}], "*)"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getOmega", "[", 
     RowBox[{"n_", ",", "n\[Prime]_"}], "]"}], "=", 
    RowBox[{"N", "[", 
     RowBox[{"R", "*", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "1"}], 
          RowBox[{"(", 
           RowBox[{"n", "^", "2"}], ")"}]], "-", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"-", "1"}], 
           RowBox[{"(", 
            RowBox[{"n\[Prime]", "^", "2"}], ")"}]], ")"}]}], ")"}], 
       "\[HBar]"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Function", " ", "to", " ", "get", " ", "angular", " ", "momentum", " ", 
    "from", " ", "quantum", " ", "state"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"powerQuantumApproach", "[", 
     RowBox[{
     "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
      "l\[Prime]_"}], "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"\[HBar]", "*", 
        RowBox[{"\[Omega]", "^", "4"}], "*", 
        RowBox[{"Max", "[", 
         RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"3", 
        RowBox[{"\[Pi]", "^", "3"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l"}], "+", "1"}], ")"}], "*", 
        RowBox[{"Ry", "^", "3"}]}], ")"}]], "*", 
     RowBox[{"dif", "[", 
      RowBox[{"n", ",", "n\[Prime]", ",", "l"}], "]"}], "*", 
     RowBox[{"10", "^", "9"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Power", " ", "formula", " ", "in", " ", "quantum", " ", "approach", " ", 
    RowBox[{"pg", ".", " ", "47"}], " ", "Jasper"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"powerQuantumData", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"getOmega", "[", 
         RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
        RowBox[{"powerQuantumApproach", "[", 
         RowBox[{
          RowBox[{"getOmega", "[", 
           RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", "n\[Prime]",
           ",", "l", ",", 
          RowBox[{"l", "-", "1"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n\[Prime]", ",", "l", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plot", " ", "a", " ", "table", " ", "of", " ", "n"}], ",", " ", 
    "n\[Prime]", ",", " ", "\[Omega]", ",", " ", "Power"}], "*)"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"quantumPowerPlot", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"powerQuantumData", ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", ".01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "->", "All"}], ",", 
      RowBox[{"PlotLegends", "->", 
       RowBox[{"{", "\"\<Quantum Approach\>\"", "}"}]}]}], "]"}]}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "0"], "=", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"n", "^", "3"}], "*", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"2", "\[Pi]", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "\[Pi]"}], ")"}], "^", "2"}], "*", 
          RowBox[{
           SubscriptBox["\[Epsilon]", "0"], "^", "2"}], "*", 
          RowBox[{"\[HBar]", "^", "3"}]}], ")"}], 
        RowBox[{"m", "*", 
         RowBox[{"e", "^", "4"}]}]]}], ")"}]]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{"Find", " ", "Omega", " ", "Naught"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"maxK", "=", 
   FractionBox[
    RowBox[{"N", "[", 
     RowBox[{"R", "*", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "1"}], 
          RowBox[{"(", 
           RowBox[{"n", "^", "2"}], ")"}]], "-", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"-", "1"}], 
           RowBox[{"(", 
            RowBox[{"l", "^", "2"}], ")"}]], ")"}]}], ")"}], "\[HBar]"]}], 
     "]"}], 
    SubscriptBox["\[Omega]", "0"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"besselJPrime", "[", 
     RowBox[{"v_", ",", "z_"}], "]"}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", "2"], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"BesselJ", "[", 
        RowBox[{
         RowBox[{"v", "-", "1"}], ",", "z"}], "]"}], "-", 
       RowBox[{"BesselJ", "[", 
        RowBox[{
         RowBox[{"v", "+", "1"}], ",", "z"}], "]"}]}], ")"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "First", " ", "Derivative", " ", "of", " ", "the", " ", "Bessel", " ", 
    "Function"}], "*)"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"powerSemiClassicalApproach", "[", "k_", "]"}], "=", " ", 
   RowBox[{
    RowBox[{"(", 
     FractionBox[
      RowBox[{"e", "^", "2"}], 
      RowBox[{"3", "\[Pi]", "*", 
       SubscriptBox["\[Epsilon]", "0"], "*", 
       RowBox[{"c", "^", "3"}]}]], ")"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k", "*", 
       SubscriptBox["\[Omega]", "0"]}], ")"}], "^", "4"}], "*", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"a", "^", "2"}], 
      RowBox[{"k", "^", "2"}]], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"besselJPrime", "[", 
        RowBox[{"k", ",", 
         RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "^", "2"}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox["\[Epsilon]", "2"]}], 
         SuperscriptBox["\[Epsilon]", "2"]], ")"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"BesselJ", "[", 
          RowBox[{"k", ",", 
           RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}], "^", "2"}]}]}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"powerSemiClassicalData", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k", "*", 
         SubscriptBox["\[Omega]", "0"]}], ",", 
        RowBox[{"powerSemiClassicalApproach", "[", "k", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "maxK"}], "}"}]}], "]"}]}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"semiClassicalPowerPlot", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"powerSemiClassicalData", ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"PointSize", "[", ".01", "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRange", "->", "All"}], ",", 
      RowBox[{"PlotLegends", "->", 
       RowBox[{"{", "\"\<Semi-Classical Approach\>\"", "}"}]}]}], "]"}]}], 
   ";"}], "\n"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"quantumPowerPlot", ",", "semiClassicalPowerPlot", ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
      "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
   RowBox[{"PlotLabel", " ", "->", 
    RowBox[{"Style", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
       "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}], 
       "[", 
       RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.900064043731151*^9, {3.900064084679411*^9, 3.900064126266266*^9}, 
   3.900066556133506*^9, 3.9000756365475984`*^9, {3.9000757937039623`*^9, 
   3.900075800556555*^9}, 3.9000758439825983`*^9, {3.90007646952641*^9, 
   3.900076485884135*^9}, {3.900076686487694*^9, 3.900076712104075*^9}, 
   3.900076744081128*^9, 3.90007679405513*^9, {3.90007750165366*^9, 
   3.9000775028130302`*^9}, {3.900077727548106*^9, 3.9000777278017006`*^9}, {
   3.9000779273164263`*^9, 3.9000779420554843`*^9}, {3.900077996787839*^9, 
   3.9000780046327286`*^9}, {3.900078035812394*^9, 3.9000780506935024`*^9}, 
   3.9000781211097937`*^9, 3.900078160336017*^9, {3.9000781958335733`*^9, 
   3.900078220092637*^9}, 3.9000783003737106`*^9, {3.900078342352115*^9, 
   3.9000783430017586`*^9}, 3.9000785415048637`*^9, {3.9001492875786977`*^9, 
   3.9001493368296947`*^9}, {3.9001506490802917`*^9, 3.900150702544808*^9}, {
   3.9001641555164213`*^9, 3.9001641561698923`*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[409]:=",ExpressionUUID->"3475e8e0-19ed-4166-baac-b0642f35da3e"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{}, {{{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0], 
          PointSize[0.01]], 
         PointBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAAzwXRk1qPlkJ1JxBD+eaBOWdhEspV
ZJVCVtj2TFgnvDmm/VSsZkqUQqZH/rzBQuc5lGxcRkZAk0KaSWRlTeEKOjsE
faHLRJJCluh115hmKDrpnsSG6FaRQnr4Wc9LiEI6MWbtp6Z1kEJJFs0VA4BY
OkXwnEFKQI9CY1/fk6/0bDqPVWKKLKuNQtems9skMX86KyKMYXsqjEJv5Pko
DxOPOgi79yDdvIpCvRr65Uj0nDqDU4M7FGGJQhXZX2u2dak6f2yiivwViELA
7h4Nxke1OhzkCuiI2oZC9LDL7zoCwTqU2woKwa2FQism5/L1IMo6MZVjmr+O
hEKtl8/UIF7TOgBln4CwfINCUE+vk5bO2zpwA8lZz3aCQt6Ytag5ZOM6jLY3
GGZ8gULZEABzoFfqOiVp08bLjIBCWnnWhHx38TrVApXXxk5/QgTKvEVQqPY6
3t1pDjaXfUKUErO4ksz8OndbH1XV8XtC/AxFbzb2ATvDGblMp116QsRc62Ry
BAY7aUULl7/ZeEI5/46Ji40KO6fD2HxBZXdCUSOrBtuJDztAoJazXv91QiDa
gIG0dhI7U5mQP1andEKjogh5+lMVO0J8im9zXHNCvluGA5BSGDsH003vDB5y
QtTOXDBbZhs7WsTc7oPrcEKfbhFBiYEeOwrXhriGiG9Csd+SgWXKIDtuA3Nc
fk9tQmBc4YrMRyI77QHwe+cqa0KRBI+yPrAjOyGlpF3KGWlCzVc/n6/6JDuE
w5LEPRtnQhxYVsfnHSY7Z27i7mUuZUKDx+KMqRAnO6hDQKlzUmNCTwKjX9TJ
Jzsnx/J0o4ZhQqJx5A+FQCg7Lx71fXmUX0J16mOZMmwoO2pFd00iOVxC+8gi
v8ZEKDvTr6il9/lYQo9lpM+xwic79aDPpcHVVUIHO6XE+N4mO9TYgBpZy1JC
9aUGizyTJTuILCbdTLNPQufqiFS42SM70o7gX0H/SULG2bfNMq0hOyqrPU2Z
eERCEht/MLMRHjsuiBHy7zo+QitSO1Pqzxc7Bv8Y0jHYM0Kw7wtIvIoQOw9H
W345iyNCGkzQc/5vADtyZnNV
          "]]}}}, {{}, {}}}, {{}, {{{
         Directive[
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1], 
          PointSize[0.01]], 
         PointBox[CompressedData["
1:eJw1lHk8VOsfx1FXI1nqZpDbgrquynJt6Tnl6mup3DRJYibZsidZsk/WMRTD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          "]]}}}, {{}, {}}}}, {AxesLabel -> {
       FormBox[
       "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
        TraditionalForm], 
       FormBox["\"Power (Watts)\"", TraditionalForm]}, PlotLabel -> FormBox[
       StyleBox["\"Transition from n=100, l=50\"", 
        GrayLevel[0], StripOnInput -> False], TraditionalForm], PlotRange -> 
     All, DisplayFunction -> Identity, DisplayFunction -> Identity, 
     AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 6.201238942785452*^12}, {0, 1.0100970086821574`*^-23}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{"\"Quantum Approach\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    PointSize[0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0], 
                    PointSize[0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"PointSize", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{"\"Semi-Classical Approach\""}, "PointLegend", 
          DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    PointSize[0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    PointSize[0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"PointLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    
                    TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                    RowBox[{"PointSize", "[", "0.01`", "]"}]}], "]"}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], "}"}]}], ",", 
               RowBox[{"Joined", "\[Rule]", 
                 RowBox[{"{", "False", "}"}]}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.900076789140814*^9, 3.9000768130779076`*^9}, 
   3.9000768476350384`*^9, {3.900076880938544*^9, 3.900076905836073*^9}, 
   3.900077126073842*^9, {3.9000775053020067`*^9, 3.9000777376471844`*^9}, {
   3.900077914127632*^9, 3.900077943139332*^9}, {3.9000780070564566`*^9, 
   3.900078052516197*^9}, {3.9000780910930433`*^9, 3.900078123755705*^9}, 
   3.900078177799261*^9, {3.90007821463351*^9, 3.9000782223313875`*^9}, {
   3.900078321026496*^9, 3.900078353784099*^9}, 3.9000815371281424`*^9, {
   3.9000819108339157`*^9, 3.9000819464064865`*^9}, {3.900148947290615*^9, 
   3.900148957650732*^9}, {3.900149342248563*^9, 3.9001493439976826`*^9}, 
   3.900149531051774*^9, 3.9001507079486556`*^9, 3.9001640818403397`*^9, 
   3.900164157938929*^9, {3.900164792842089*^9, 3.900164802759966*^9}, 
   3.900164874331777*^9},
 CellLabel->
  "Out[420]=",ExpressionUUID->"bc9974b1-9855-42f9-bbb3-51c93cc506a6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Quantum Power Curve Jasper vs Horbatsch", "Section",
 CellChangeTimes->{{3.9000645878533945`*^9, 3.900064601884342*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"8be239ca-3735-4d41-9b65-d4ab685734a1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dif", "[", 
     RowBox[{"n_", ",", " ", "n\[Prime]_", ",", " ", "l_"}], "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", " ", 
     RowBox[{
      RowBox[{"n\[Prime]", " ", "==", "n"}], ",", " ", 
      RowBox[{
       RowBox[{"output", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.5", "*", "n", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"n", "^", "2"}], " ", "-", " ", 
              RowBox[{"l", "^", "2"}]}], ")"}], "^", 
            RowBox[{"(", "0.5", ")"}]}]}], ")"}], "^", 
         RowBox[{"(", "2", ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"IntegerPart", "[", "output", "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"output", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], 
           RowBox[{"(", 
            RowBox[{"4", "*", 
             RowBox[{"Factorial", "[", 
              RowBox[{
               RowBox[{"2", "*", "l"}], "-", "1"}], "]"}]}], ")"}]], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"Factorial", "[", 
             RowBox[{"n", "+", "l"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Factorial", "[", 
               RowBox[{"n\[Prime]", "+", "l", "-", "1"}], "]"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Factorial", "[", 
                 RowBox[{"n", "-", "l", "-", "1"}], "]"}], "*", 
                RowBox[{"Factorial", "[", 
                 RowBox[{"n\[Prime]", "-", "l"}], "]"}]}], ")"}]}], ")"}]}], 
           "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"n", "+", "n\[Prime]", "-", 
                 RowBox[{"2", "*", "l"}], "-", "2"}], ")"}]}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "*", "n", "*", "n\[Prime]"}], ")"}], "^", 
               RowBox[{"(", 
                RowBox[{"l", "+", "1"}], ")"}]}]}], ")"}], "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"n", "+", "n\[Prime]"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"n", "+", "n\[Prime]"}], ")"}]}]}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Hypergeometric2F1", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], ",", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
              RowBox[{"2", "*", "l"}], ",", 
              FractionBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], "]"}],
             "-", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"n", "+", "n\[Prime]"}], ")"}]], ")"}], "^", "2"}], 
             "*", 
             RowBox[{"Hypergeometric2F1", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], "-", "2"}], ",", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
               RowBox[{"2", "*", "l"}], ",", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
              "]"}]}]}], ")"}]}], ")"}], "^", "2"}]}]}], "]"}]}], ";"}], "  ",
   "\n", 
  RowBox[{"(*", 
   RowBox[{"Dipole", " ", "Moment", " ", "Function"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getOmega", "[", 
     RowBox[{"n_", ",", "n\[Prime]_"}], "]"}], "=", 
    RowBox[{"N", "[", 
     RowBox[{"R", "*", 
      FractionBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "1"}], 
          RowBox[{"(", 
           RowBox[{"n", "^", "2"}], ")"}]], "-", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"-", "1"}], 
           RowBox[{"(", 
            RowBox[{"n\[Prime]", "^", "2"}], ")"}]], ")"}]}], ")"}], 
       "\[HBar]"]}], "]"}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{
   "Function", " ", "to", " ", "get", " ", "angular", " ", "momentum", " ", 
    "from", " ", "quantum", " ", "state"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"powerQuantumApproach", "[", 
     RowBox[{
     "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
      "l\[Prime]_"}], "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"\[HBar]", "*", 
        RowBox[{"\[Omega]", "^", "4"}], "*", 
        RowBox[{"Max", "[", 
         RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"3", 
        RowBox[{"\[Pi]", "^", "3"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l"}], "+", "1"}], ")"}], "*", 
        RowBox[{"Ry", "^", "3"}]}], ")"}]], "*", 
     RowBox[{"dif", "[", 
      RowBox[{"n", ",", "n\[Prime]", ",", "l"}], "]"}], "*", 
     RowBox[{"10", "^", "9"}]}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{
   "Power", " ", "formula", " ", "in", " ", "quantum", " ", "approach", " ", 
    RowBox[{"pg", ".", " ", "47"}], " ", "Jasper"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"powerQuantumJasperData", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"getOmega", "[", 
         RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
        RowBox[{"powerQuantumApproach", "[", 
         RowBox[{
          RowBox[{"getOmega", "[", 
           RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", "n\[Prime]",
           ",", "l", ",", 
          RowBox[{"l", "-", "1"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n\[Prime]", ",", "l", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plot", " ", "a", " ", "table", " ", "of", " ", "n"}], ",", " ", 
    "n\[Prime]", ",", " ", "\[Omega]", ",", " ", "Power"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"horbatschTransitionRate", "[", 
     RowBox[{"n_", ",", "n\[Prime]_", ",", "l_", ",", "l\[Prime]_"}], "]"}], 
    "=", 
    RowBox[{"2.85533719185295`*^-21", "*", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Alpha]", "7"], "*", 
       SuperscriptBox["m", "3"], "*", 
       SuperscriptBox["c", "4"], "*", "1", "*", 
       RowBox[{"Max", "[", 
        RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], 
      RowBox[{"6", 
       SuperscriptBox["\[HBar]", "3"], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "l"}], "+", "1"}], ")"}]}]], "*", 
     RowBox[{"dif", "[", 
      RowBox[{"n", ",", "n\[Prime]", ",", "l"}], "]"}], "*", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["n\[Prime]", "2"]], "-", 
        FractionBox["1", 
         SuperscriptBox["n", "2"]]}], ")"}], "3"]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"from", " ", "eq", " ", "10", " ", "of", " ", 
    RowBox[{"Horbatsch", ".", " ", "scaled"}], " ", "by", " ", "coefficient", 
    " ", "at", " ", "front", " ", "because", " ", "some", " ", "mismatch", 
    " ", "in", " ", "units"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"horbatschpower", "[", 
     RowBox[{
     "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
      "l\[Prime]_"}], "]"}], "=", 
    RowBox[{
     RowBox[{"horbatschTransitionRate", "[", 
      RowBox[{"n", ",", "n\[Prime]", ",", "l", ",", "l\[Prime]"}], "]"}], "*",
      "\[HBar]", "*", "\[Omega]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"powerQuantumHorbatschData", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"getOmega", "[", 
         RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
        RowBox[{"horbatschpower", "[", 
         RowBox[{
          RowBox[{"getOmega", "[", 
           RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", "n\[Prime]",
           ",", "l", ",", 
          RowBox[{"l", "-", "1"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n\[Prime]", ",", "l", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Plot", " ", "a", " ", "table", " ", "of", " ", "n"}], ",", " ", 
    "n\[Prime]", ",", " ", "\[Omega]", ",", " ", "Power"}], "*)"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"powerQuantumHorbatschData", ",", "powerQuantumJasperData"}], 
    "}"}], ",", 
   RowBox[{"PlotLegends", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<Horbatsch\>\"", ",", "\"\<Jasper\>\""}], "}"}]}], ",", 
   RowBox[{"PlotMarkers", "->", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "3"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
      "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
   RowBox[{"PlotLabel", " ", "->", 
    RowBox[{"Style", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
       "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}], 
       "[", 
       RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.90006460852985*^9, 3.9000646325759125`*^9}, 
   3.9000666750018063`*^9, 3.9000676794756517`*^9, {3.9000679883993397`*^9, 
   3.9000679885492597`*^9}, {3.900076138056385*^9, 3.9000761738837504`*^9}, 
   3.9000762921574326`*^9, {3.9000763595243707`*^9, 3.900076382310032*^9}, 
   3.900076432716691*^9, 3.900076481553636*^9, {3.900076518698261*^9, 
   3.9000766135541525`*^9}, {3.9000768047166357`*^9, 
   3.9000768355991936`*^9}, {3.900076867848601*^9, 3.90007689741763*^9}, {
   3.900077035122592*^9, 3.900077065189433*^9}, {3.900077104619377*^9, 
   3.900077105522196*^9}, 3.900078292568038*^9, {3.9000783704645967`*^9, 
   3.900078371464137*^9}, {3.900081554588166*^9, 3.9000815547792625`*^9}, {
   3.900081614456957*^9, 3.9000817103056183`*^9}, {3.9000818352256875`*^9, 
   3.9000818369368677`*^9}, {3.900081921528754*^9, 3.900081922136077*^9}, {
   3.9001493544010067`*^9, 3.900149386983467*^9}, {3.900164162504674*^9, 
   3.900164163010232*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[328]:=",ExpressionUUID->"ec8d2b3c-31fe-48a2-87ba-66e714a12276"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.009166666666666668], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.009166666666666668], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[3]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM8F0ZNaj5ZCiNfo2cpTgjln
YRLKVWSVQprHBR960rw5pv1UrGZKlEJ/6c20JdDnOZRsXEZGQJNCf7cqXrGE
Czo7BH2hy0SSQlnKcsLq+ig66Z7EhuhWkUJ2e0b/8fhCOjFm7aemdZBC5JH3
fO8UWTpF8JxBSkCPQjP974+xpG06j1ViiiyrjUK+awyHvu5/OisijGF7KoxC
4vqT9fHPjzoIu/cg3byKQnf/53FIpJ06g1ODOxRhiUIdo+tPeBCqOn9soor8
FYhCD+jvUiDJtToc5AroiNqGQlThERyeacE6lNsKCsGthULkdN/FyL/KOjGV
Y5q/joRCFq/Wy9rT0zoAZZ+AsHyDQkJ00+Ocd9w6cAPJWc92gkIXDjmvGNrj
Ooy2NxhmfIFCeLh9j7/36joladPGy4yAQrX44G6o4fE61QKV18ZOf0JB5jN1
CTL3Ot7daQ42l31CdwyP4aB7/Tp3Wx9V1fF7QlFmYadkYwI7wxm5TKddekI9
7jKER4oGO2lFC5e/2XhCa1ESZPIuCzunw9h8QWV3QlhN2PbHJBA7QKCWs17/
dULP9xvE7+YSO1OZkD9Wp3RCcZ+i7p7VFTtCfIpvc1xzQntc8yZo5hg7B9NN
7wweckJx5p/t5wwcO1rE3O6D63BCLm7vffc6HzsK14a4hohvQlPwR0t1MCE7
bgNzXH5PbUI6nh+v6rYiO+0B8HvnKmtCxurszusnJDshpaRdyhlpQmzrZ1E1
eiU7hMOSxD0bZ0L+2oOmV6QmO2du4u5lLmVCIIrqBN2cJzuoQ0Cpc1JjQkJW
j2FtWig7J8fydKOGYUJXZQmH79MoOy8e9X15lF9CZN13j6YAKTtqRXdNIjlc
QjeC7BVL2Cg706+opff5WEJI0c9yH1MoO/Wgz6XB1VVCukRyMf5pJzvU2IAa
WctSQiLpOYRhFiY7iCwm3UyzT0Ib+SSMYVIkO9KO4F9B/0lCcNvQNKUYIjsq
qz1NmXhEQtHonaF5yB47LogR8u86PkKwZShTqGAYOwb/GNIx2DNCoZ4hG0nv
EDsPR1t+OYsjQhcGjbro0wA7oUN8Wg==
         "]]}, {
        Directive[
         PointSize[0.009166666666666668], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.009166666666666668], 
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[3]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM8F0ZNaj5ZCdScQQ/nmgTln
YRLKVWSVQlbY9kxYJ7w5pv1UrGZKlEKmR/68wULnOZRsXEZGQJNCmklkZU3h
Cjo7BH2hy0SSQpboddeYZig66Z7EhuhWkUJ6+FnPS4hCOjFm7aemdZBCSRbN
FQOAWDpF8JxBSkCPQmNf35Ov9Gw6j1ViiiyrjULXprPbJDF/OisijGF7KoxC
b+T5KA8TjzoIu/cg3byKQr0a+uVI9Jw6g1ODOxRhiUIV2V9rtnWpOn9soor8
FYhCwO4eDcZHtToc5AroiNqGQvSwy+86AsE6lNsKCsGthUIrJufy9SDKOjGV
Y5q/joRCrZfP1CBe0zoAZZ+AsHyDQlBPr5OWzts6cAPJWc92gkLemLWoOWTj
Ooy2NxhmfIFC2RAAc6BX6joladPGy4yAQlp51oR8d/E61QKV18ZOf0IEyrxF
UKj2Ot7daQ42l31ClBKzuJLM/Dp3Wx9V1fF7QvwMRW829gE7wxm5TKddekLE
XOtkcgQGO2lFC5e/2XhCOf+OiYuNCjunw9h8QWV3QlEjqwbbiQ87QKCWs17/
dUIg2oCBtHYSO1OZkD9Wp3RCo6IIefpTFTtCfIpvc1xzQr5bhgOQUhg7B9NN
7wweckLUzlwwW2YbO1rE3O6D63BCn24RQYmBHjsK14a4hohvQrHfkoFlyiA7
bgNzXH5PbUJgXOGKzEciO+0B8HvnKmtCkQSPsj6wIzshpaRdyhlpQs1XP5+v
+iQ7hMOSxD0bZ0IcWFbH5x0mO2du4u5lLmVCg8fijKkQJzuoQ0Cpc1JjQk8C
o1/UySc7J8fydKOGYUKiceQPhUAoOy8e9X15lF9CdepjmTJsKDtqRXdNIjlc
QvvIIr/GRCg706+opff5WEKPZaTPscInO/Wgz6XB1VVCBzulxPjeJjvU2IAa
WctSQvWlBos8kyU7iCwm3UyzT0Ln6ohUuNkjO9KO4F9B/0lCxtm3zTKtITsq
qz1NmXhEQhIbfzCzER47LogR8u86PkIrUjtT6s8XOwb/GNIx2DNCsO8LSLyK
EDsPR1t+OYsjQhpM0HP+bwA7gDZzVw==
         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox[
        "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
         HoldForm], TraditionalForm], 
       FormBox[
        TagBox["\"Power (Watts)\"", HoldForm], TraditionalForm]}, 
     AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> FormBox[
       StyleBox["\"Transition from n=100, l=50\"", 
        GrayLevel[0], StripOnInput -> False], TraditionalForm], 
     PlotRange -> {{0, 6.201238942785452*^12}, {0, 1.034080880095971*^-23}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"Horbatsch\"", "\"Jasper\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 3}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.6233333333333334] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 3}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.6233333333333334] -> 
                    Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "3", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "3", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.9000768980943723`*^9, 3.900076909317811*^9}, 
   3.900077036062083*^9, 3.9000770760644684`*^9, 3.9000771266935616`*^9, {
   3.9000783541039286`*^9, 3.9000783751305356`*^9}, {3.900081537317993*^9, 
   3.9000815555343704`*^9}, {3.900081617008373*^9, 3.900081644282279*^9}, 
   3.9000816748145103`*^9, {3.9000817065984135`*^9, 3.9000817109114323`*^9}, {
   3.900081830599286*^9, 3.9000818381750345`*^9}, {3.9000819110493407`*^9, 
   3.900081946581021*^9}, {3.900148947690401*^9, 3.9001489578406315`*^9}, {
   3.900149384206194*^9, 3.9001493889723988`*^9}, 3.900149531221633*^9, 
   3.9001640820302906`*^9, 3.9001641689141397`*^9, {3.9001647930718994`*^9, 
   3.900164802929824*^9}},
 CellLabel->
  "Out[335]=",ExpressionUUID->"c3ce60ba-0f15-477a-bb0c-cce2817bcb2c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semi-Classical Jasper vs Horbatsch", "Section",
 CellChangeTimes->{{3.900064982034927*^9, 3.9000649902110195`*^9}, {
  3.900067739791133*^9, 3.90006774048077*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"197ad755-1ac2-45c7-b9c8-68cab04ffb4a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"horbatsch", "'"}], "s", " ", "semi"}], "-", 
    RowBox[{"classical", " ", "approach"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"j", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["n", "2"], "*", 
       RowBox[{"(", 
        RowBox[{"4", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"]}], ")"}], "*", 
       SuperscriptBox["\[HBar]", "2"]}], 
      RowBox[{"m", "*", 
       SuperscriptBox["e", "2"]}]]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"Definition", " ", "for", " ", "a"}], "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "0"], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["n", "3"]], "*", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"m", "*", 
         SuperscriptBox["e", "4"]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "*", "\[Pi]", "*", 
            SubscriptBox["\[Epsilon]", "0"]}], ")"}], "2"], "*", 
         SuperscriptBox["\[HBar]", "3"]}]], ")"}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"angular", " ", "frequency", " ", "reduction"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"frequency", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "0"], "*", "k"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"maxK", "=", 
     FractionBox[
      RowBox[{"N", "[", 
       RowBox[{"R", "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n", "^", "2"}], ")"}]], "-", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"-", "1"}], 
             RowBox[{"(", 
              RowBox[{"l", "^", "2"}], ")"}]], ")"}]}], ")"}], "\[HBar]"]}], 
       "]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"upTrans", "[", "k_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["j", "2"], "*", 
        SuperscriptBox["e", "2"], "*", 
        SuperscriptBox[
         SubscriptBox["\[Omega]", "0"], "3"], "*", "k"}], 
       RowBox[{
        RowBox[{"6", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", 
         SuperscriptBox["c", "3"]}], "\[IndentingNewLine]"}]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{"1", "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}], 
         "-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", 
               SuperscriptBox["\[Epsilon]", "2"]}], 
              SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"BesselJ", "[", 
             RowBox[{"k", ",", 
              RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], 
        ")"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"downTrans", "[", "k_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["j", "2"], "*", 
        SuperscriptBox["e", "2"], "*", 
        SuperscriptBox[
         SubscriptBox["\[Omega]", "0"], "3"], "*", "k"}], 
       RowBox[{
        RowBox[{"6", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", 
         SuperscriptBox["c", "3"]}], "\[IndentingNewLine]"}]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{"1", "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}], 
         "+", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", 
               SuperscriptBox["\[Epsilon]", "2"]}], 
              SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"BesselJ", "[", 
             RowBox[{"k", ",", 
              RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], 
        ")"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerSemiClassicalHorbatschData", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"frequency", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"upTrans", "[", "k", "]"}], "+", 
            RowBox[{"downTrans", "[", "k", "]"}]}], ")"}], "*", "\[HBar]", 
          "*", "frequency"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "maxK"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Jasper", " ", "Approach"}], "*)"}], "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "0"], "=", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", "^", "3"}], "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", "\[Pi]"}], ")"}], "^", "2"}], "*", 
           RowBox[{
            SubscriptBox["\[Epsilon]", "0"], "^", "2"}], "*", 
           RowBox[{"\[HBar]", "^", "3"}]}], ")"}], 
         RowBox[{"m", "*", 
          RowBox[{"e", "^", "4"}]}]]}], ")"}]]}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"Find", " ", "Omega", " ", "Naught"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"maxK", "=", 
     FractionBox[
      RowBox[{"N", "[", 
       RowBox[{"R", "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n", "^", "2"}], ")"}]], "-", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"-", "1"}], 
             RowBox[{"(", 
              RowBox[{"l", "^", "2"}], ")"}]], ")"}]}], ")"}], "\[HBar]"]}], 
       "]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"besselJPrime", "[", 
      RowBox[{"v_", ",", "z_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "2"], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"BesselJ", "[", 
         RowBox[{
          RowBox[{"v", "-", "1"}], ",", "z"}], "]"}], "-", 
        RowBox[{"BesselJ", "[", 
         RowBox[{
          RowBox[{"v", "+", "1"}], ",", "z"}], "]"}]}], ")"}]}]}], " ", 
    RowBox[{"(*", 
     RowBox[{
     "First", " ", "Derivative", " ", "of", " ", "the", " ", "Bessel", " ", 
      "Function"}], "*)"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"powerSemiClassicalApproach", "[", 
      RowBox[{"k_", ",", "n_", ",", "l_"}], "]"}], "=", " ", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"e", "^", "2"}], 
        RowBox[{"3", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", 
         RowBox[{"c", "^", "3"}]}]], ")"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"k", "*", 
         SubscriptBox["\[Omega]", "0"]}], ")"}], "^", "4"}], "*", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"a", "^", "2"}], 
        RowBox[{"k", "^", "2"}]], ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"besselJPrime", "[", 
          RowBox[{"k", ",", 
           RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "^", "2"}], " ", "+", 
        RowBox[{
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "-", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           SuperscriptBox["\[Epsilon]", "2"]], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"BesselJ", "[", 
            RowBox[{"k", ",", 
             RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}], "^", "2"}]}]}],
        ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"powerSemiClassicalJasperData", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k", "*", 
          SubscriptBox["\[Omega]", "0"]}], ",", 
         RowBox[{"powerSemiClassicalApproach", "[", 
          RowBox[{"k", ",", "n", ",", "l"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "maxK"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "powerSemiClassicalHorbatschData", ",", 
       "powerSemiClassicalJasperData"}], "}"}], ",", " ", 
     RowBox[{"PlotLegends", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<Horbatsch\>\"", ",", "\"\<Jasper\>\""}], "}"}]}], ",", 
     RowBox[{"PlotMarkers", "->", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "2"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
        "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
     RowBox[{"PlotLabel", " ", "->", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
         "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}],
          "[", 
         RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.9000650098960857`*^9, 3.9000650147438383`*^9}, {
   3.900065047237862*^9, 3.900065053850889*^9}, 3.9000665802858934`*^9, {
   3.9000666630581894`*^9, 3.900066664677739*^9}, 3.9000677158461695`*^9, {
   3.900068267042321*^9, 3.90006835928343*^9}, {3.900075542741088*^9, 
   3.900075585051754*^9}, {3.9000762152498655`*^9, 3.9000762157603455`*^9}, {
   3.900076260414543*^9, 3.9000762804364433`*^9}, {3.9000763206834135`*^9, 
   3.9000763324776692`*^9}, {3.9000771114513173`*^9, 
   3.9000771130544815`*^9}, {3.9001494060064187`*^9, 3.9001494151755347`*^9}, 
   3.900164173341881*^9},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[336]:=",ExpressionUUID->"888551a4-593b-44ca-bebe-ea960d7018d3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{
        Directive[
         PointSize[0.007333333333333334], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               DiskBox[{0, 0}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.007333333333333334], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[2]], CompressedData["
1:eJw1lHk4lOsfxlFZWlCHkZzKkvqppLKk55X0tVR+JGQbssVkS8a+TBjL2AbD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         "]]}, {
        Directive[
         PointSize[0.007333333333333334], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        GeometricTransformationBox[
         InsetBox[
          BoxData[
           FormBox[
            StyleBox[
             GraphicsBox[{
               EdgeForm[], 
               PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
             GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                 PointSize[0.007333333333333334], 
                 RGBColor[0.880722, 0.611041, 0.142051], 
                 AbsoluteThickness[1.6]]}, StripOnInput -> False], 
            TraditionalForm]], {0., 0.}, Automatic, 
          Offset[2]], CompressedData["
1:eJw1lHk81NsfxlFXI1nqZpDbgvr5qSzXls636+pjqdw0SWIm2bInWbJP1jEU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         "]]}}}, {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox[
        TagBox[
        "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
         HoldForm], TraditionalForm], 
       FormBox[
        TagBox["\"Power (Watts)\"", HoldForm], TraditionalForm]}, 
     AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[1.6]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
       "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
       Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
       True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> FormBox[
       StyleBox["\"Transition from n=100, l=50\"", 
        GrayLevel[0], StripOnInput -> False], TraditionalForm], 
     PlotRange -> {{0, 6.201238942785452*^12}, {0, 7.3511934199747*^-24}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"Horbatsch\"", "\"Jasper\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 2}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-1.14] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 2}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-1.14] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "2", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "2", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.900065019486969*^9, 3.9000650575293818`*^9}, {
   3.900067178762849*^9, 3.900067216139911*^9}, 3.900067282752221*^9, 
   3.9000677238477955`*^9, {3.9000683617030373`*^9, 3.900068363840311*^9}, {
   3.9000755542396936`*^9, 3.9000755873879027`*^9}, 3.9000757754828176`*^9, {
   3.9000762177893143`*^9, 3.9000762822001896`*^9}, 3.900076335626389*^9, 
   3.900077128172724*^9, 3.9000783557513556`*^9, 3.9000815383074646`*^9, {
   3.900081912090557*^9, 3.9000819469889297`*^9}, {3.9001489482101727`*^9, 
   3.900148958251396*^9}, 3.900149417844053*^9, 3.900149531621419*^9, 
   3.9001640824500666`*^9, 3.90016417418141*^9, {3.9001647936336813`*^9, 
   3.9001648033254223`*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "Out[348]=",ExpressionUUID->"9eb1d5b2-4a5f-4434-bc94-2a3e296a413e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Semi-Classical Horbatsch Scaled vs Quantum", "Section",
 CellChangeTimes->{{3.9001508605509577`*^9, 3.9001508642459135`*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"7d991649-df99-4fc9-bad4-c1855df192ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Jasper", " ", "Quantum", " ", "approach"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dif", "[", 
      RowBox[{"n_", ",", " ", "n\[Prime]_", ",", " ", "l_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{"n\[Prime]", " ", "==", "n"}], ",", " ", 
       RowBox[{
        RowBox[{"output", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.5", "*", "n", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"n", "^", "2"}], " ", "-", " ", 
               RowBox[{"l", "^", "2"}]}], ")"}], "^", 
             RowBox[{"(", "0.5", ")"}]}]}], ")"}], "^", 
          RowBox[{"(", "2", ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"IntegerPart", "[", "output", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"output", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], 
            RowBox[{"(", 
             RowBox[{"4", "*", 
              RowBox[{"Factorial", "[", 
               RowBox[{
                RowBox[{"2", "*", "l"}], "-", "1"}], "]"}]}], ")"}]], "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"Factorial", "[", 
              RowBox[{"n", "+", "l"}], "]"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Factorial", "[", 
                RowBox[{"n\[Prime]", "+", "l", "-", "1"}], "]"}], "/", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Factorial", "[", 
                  RowBox[{"n", "-", "l", "-", "1"}], "]"}], "*", 
                 RowBox[{"Factorial", "[", 
                  RowBox[{"n\[Prime]", "-", "l"}], "]"}]}], ")"}]}], ")"}]}], 
            "]"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"n", "+", "n\[Prime]", "-", 
                  RowBox[{"2", "*", "l"}], "-", "2"}], ")"}]}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "*", "n", "*", "n\[Prime]"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "1"}], ")"}]}]}], ")"}], "/", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", "n\[Prime]"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"n", "+", "n\[Prime]"}], ")"}]}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Hypergeometric2F1", "[", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], ",", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
               RowBox[{"2", "*", "l"}], ",", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
              "]"}], "-", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                FractionBox[
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "n\[Prime]"}], ")"}]], ")"}], "^", "2"}], 
              "*", 
              RowBox[{"Hypergeometric2F1", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], "-", "2"}], 
                ",", 
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
                RowBox[{"2", "*", "l"}], ",", 
                FractionBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
               "]"}]}]}], ")"}]}], ")"}], "^", "2"}]}]}], "]"}]}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"getOmega", "[", 
      RowBox[{"n_", ",", "n\[Prime]_"}], "]"}], "=", 
     RowBox[{"N", "[", 
      RowBox[{"R", "*", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "1"}], 
           RowBox[{"(", 
            RowBox[{"n", "^", "2"}], ")"}]], "-", 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n\[Prime]", "^", "2"}], ")"}]], ")"}]}], ")"}], 
        "\[HBar]"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"powerQuantumApproach", "[", 
      RowBox[{
      "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
       "l\[Prime]_"}], "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"(", 
        RowBox[{"\[HBar]", "*", 
         RowBox[{"\[Omega]", "^", "4"}], "*", 
         RowBox[{"Max", "[", 
          RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", 
         RowBox[{"\[Pi]", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "l"}], "+", "1"}], ")"}], "*", 
         RowBox[{"Ry", "^", "3"}]}], ")"}]], "*", 
      RowBox[{"dif", "[", 
       RowBox[{"n", ",", "n\[Prime]", ",", "l"}], "]"}], "*", 
      RowBox[{"10", "^", "9"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerQuantumData", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"getOmega", "[", 
          RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
         RowBox[{"powerQuantumApproach", "[", 
          RowBox[{
           RowBox[{"getOmega", "[", 
            RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", 
           "n\[Prime]", ",", "l", ",", 
           RowBox[{"l", "-", "1"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n\[Prime]", ",", "l", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Horbatsch", " ", "semi", " ", "classical", " ", "approach", " ", 
     "scaled"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"j", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["n", "2"], "*", 
       RowBox[{"(", 
        RowBox[{"4", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"]}], ")"}], "*", 
       SuperscriptBox["\[HBar]", "2"]}], 
      RowBox[{"m", "*", 
       SuperscriptBox["e", "2"]}]]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"Definition", " ", "for", " ", "a"}], "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "0"], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["n", "3"]], "*", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"m", "*", 
         SuperscriptBox["e", "4"]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "*", "\[Pi]", "*", 
            SubscriptBox["\[Epsilon]", "0"]}], ")"}], "2"], "*", 
         SuperscriptBox["\[HBar]", "3"]}]], ")"}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"angular", " ", "frequency", " ", "reduction"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"upTrans", "[", "k_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["j", "2"], "*", 
        SuperscriptBox["e", "2"], "*", 
        SuperscriptBox[
         SubscriptBox["\[Omega]", "0"], "3"], "*", "k"}], 
       RowBox[{
        RowBox[{"6", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", 
         SuperscriptBox["c", "3"]}], "\[IndentingNewLine]"}]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{"1", "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}], 
         "-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", 
               SuperscriptBox["\[Epsilon]", "2"]}], 
              SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"BesselJ", "[", 
             RowBox[{"k", ",", 
              RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], 
        ")"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"downTrans", "[", "k_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["j", "2"], "*", 
        SuperscriptBox["e", "2"], "*", 
        SuperscriptBox[
         SubscriptBox["\[Omega]", "0"], "3"], "*", "k"}], 
       RowBox[{
        RowBox[{"6", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", 
         SuperscriptBox["c", "3"]}], "\[IndentingNewLine]"}]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{"1", "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}], 
         "+", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", 
               SuperscriptBox["\[Epsilon]", "2"]}], 
              SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"BesselJ", "[", 
             RowBox[{"k", ",", 
              RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], 
        ")"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"kScaler", "[", "nPrime_", "]"}], " ", ":=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "nPrime"}], ")"}], "/", "n"}]}], ")"}], 
      RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"omegaQuantum", "[", "nPrime_", "]"}], " ", ":=", " ", 
     RowBox[{"R", "*", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], 
         SuperscriptBox["n", "2"]], "-", 
        FractionBox[
         RowBox[{"-", "1"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"n", "-", 
            RowBox[{"(", 
             RowBox[{"n", "-", "nPrime"}], ")"}]}], ")"}], "2"]]}], 
       "\[HBar]"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"harmonicK", "[", "nPrime_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox["n", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "-", "nPrime"}], ")"}], "/", "n"}]}], ")"}], 
         RowBox[{"-", "2"}]], "-", "1"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerSemiClassicalHorbatschScaledData", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"omegaQuantum", "[", "nPrime", "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"upTrans", "[", " ", 
             RowBox[{"harmonicK", "[", "nPrime", "]"}], "]"}], "+", 
            RowBox[{"downTrans", "[", " ", 
             RowBox[{"harmonicK", "[", "nPrime", "]"}], "]"}]}], ")"}], "*", 
          "\[HBar]", "*", 
          RowBox[{"kScaler", "[", "nPrime", "]"}], "*", 
          RowBox[{"omegaQuantum", "[", "nPrime", "]"}]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"nPrime", ",", "l", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "powerSemiClassicalHorbatschScaledData", ",", "powerQuantumData"}], 
      "}"}], ",", 
     RowBox[{"PlotLegends", "->", 
      RowBox[{"Placed", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Semi-classical Horbatsch Scaled\>\"", ",", "\"\<Quantum\>\""}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{".8", ",", ".8"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"Cyan", ",", "Purple", ",", "Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotMarkers", "->", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "6"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
        "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
     RowBox[{"PlotLabel", " ", "->", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
         "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}],
          "[", 
         RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.9001509117850833`*^9, 3.900150952626959*^9}, {
  3.9001510149413643`*^9, 3.9001510491446953`*^9}, {3.900151093780992*^9, 
  3.9001510952758245`*^9}, {3.900151641944934*^9, 3.900151642910672*^9}, {
  3.900164180879801*^9, 3.900164183649953*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[349]:=",ExpressionUUID->"d147ff30-e167-4e1e-9eb7-8ed80910a617"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{}, {
      {RGBColor[0, 1, 1], PointSize[0.009166666666666668], AbsoluteThickness[
       1.6], GeometricTransformationBox[InsetBox[
         FormBox[
          StyleBox[
           GraphicsBox[
            {EdgeForm[None], DiskBox[{0, 0}]}],
           StripOnInput->False,
           GraphicsBoxOptions->{DefaultBaseStyle->Directive[
             PointSize[0.009166666666666668], 
             AbsoluteThickness[1.6], 
             RGBColor[0, 1, 1]]}],
          TraditionalForm], {0., 0.}, Automatic, Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM0F0ZNaj5ZC/iMG5xbQRTpn
YRLKVWSVQqwM1agJhFU6pv1UrGZKlELy/GKNRlBkOpNsXEZGQJNCWjwZRuFq
cjo8BH2hy0SSQj/dGQpuFYA66J7EhuhWkULApWVucyGLOjJm7aemdZBC1eYp
OJUnljpG8JxBSkCPQlsEld4ajqE6kFViiiyrjULbxF5ORg2rOioijGF7KoxC
iaLhHAZOtDoHu/cg3byKQkonaZymvr06hFODOxRhiUJlvwZ2M0vFOn5soor8
FYhCIhYd8jLXzToa5AroiNqGQh/aFA7/fdQ6lNsKCsGthUIhtvL+853bOjKV
Y5q/joRC/1Vn9d9H4joBZZ+AsHyDQmMzi5hQzOc6cAPJWc92gkJeVN9lIX7u
Ooy2NxhmfIFC84rgQXk+8zomadPGy4yAQqmIn+1U8vc61QKV18ZOf0J+9rnu
8WX9Ot3daQ42l31CWLrNZprQATt5Wx9V1fF7QkAdoOnuUwU7whm5TKddekKx
bc0McDwJO2lFC5e/2XhC1Mo7TuiGDTumw9h8QWV3QpFXKqOcFhE7QKCWs17/
dULExGk2GZMTO1SZkD9Wp3RCWXPv37wyFjtCfIpvc1xzQs8A2G/D7Rg7B9NN
7wweckK/s7ZB2LobO1rE3O6D63BCSEhWxiWPHjsK14a4hohvQsZ545w2ryA7
bgNzXH5PbUK0LDXUkg0iO/AB8HvnKmtCu5i9m1BbIzshpaRdyhlpQilfisGb
kCQ7g8OSxD0bZ0IYstTlOaUlO2Zu4u5lLmVCY3xgzqKQJjuoQ0Cpc1JjQqdI
dEUZSic7J8fydKOGYUJwR4rMw8gnOzMe9X15lF9CQrlKXsQDKDtrRXdNIjlc
QlyJnWBO8ic71q+opff5WEILzKSuuYsnO/Wgz6XB1VVCgSGmKpHHJjvY2IAa
WctSQhgyCEqanSU7iywm3UyzT0Izypjh0AUkO9mO4F9B/0lCWqXEcE34ITsx
qz1NmXhEQgGHJyv/2R47K4gR8u86PkKVSTy1B7YYOwf/GNIx2DNC5bTTgPBt
ETsfR1t+OYsjQtNGEyYqvQE7jpBuCg==
        "]]}, 
      {RGBColor[0.5, 0, 0.5], PointSize[0.009166666666666668], 
       AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
         FormBox[
          StyleBox[
           GraphicsBox[
            {EdgeForm[None], 
             PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}],
           StripOnInput->False,
           GraphicsBoxOptions->{DefaultBaseStyle->Directive[
             PointSize[0.009166666666666668], 
             AbsoluteThickness[1.6], 
             RGBColor[0.5, 0, 0.5]]}],
          TraditionalForm], {0., 0.}, Automatic, Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM8F0ZNaj5ZCdScQQ/nmgTln
YRLKVWSVQlbY9kxYJ7w5pv1UrGZKlEKmR/68wULnOZRsXEZGQJNCmklkZU3h
Cjo7BH2hy0SSQpboddeYZig66Z7EhuhWkUJ6+FnPS4hCOjFm7aemdZBCSRbN
FQOAWDpF8JxBSkCPQmNf35Ov9Gw6j1ViiiyrjULXprPbJDF/OisijGF7KoxC
b+T5KA8TjzoIu/cg3byKQr0a+uVI9Jw6g1ODOxRhiUIV2V9rtnWpOn9soor8
FYhCwO4eDcZHtToc5AroiNqGQvSwy+86AsE6lNsKCsGthUIrJufy9SDKOjGV
Y5q/joRCrZfP1CBe0zoAZZ+AsHyDQlBPr5OWzts6cAPJWc92gkLemLWoOWTj
Ooy2NxhmfIFC2RAAc6BX6joladPGy4yAQlp51oR8d/E61QKV18ZOf0IEyrxF
UKj2Ot7daQ42l31ClBKzuJLM/Dp3Wx9V1fF7QvwMRW829gE7wxm5TKddekLE
XOtkcgQGO2lFC5e/2XhCOf+OiYuNCjunw9h8QWV3QlEjqwbbiQ87QKCWs17/
dUIg2oCBtHYSO1OZkD9Wp3RCo6IIefpTFTtCfIpvc1xzQr5bhgOQUhg7B9NN
7wweckLUzlwwW2YbO1rE3O6D63BCn24RQYmBHjsK14a4hohvQrHfkoFlyiA7
bgNzXH5PbUJgXOGKzEciO+0B8HvnKmtCkQSPsj6wIzshpaRdyhlpQs1XP5+v
+iQ7hMOSxD0bZ0IcWFbH5x0mO2du4u5lLmVCg8fijKkQJzuoQ0Cpc1JjQk8C
o1/UySc7J8fydKOGYUKiceQPhUAoOy8e9X15lF9CdepjmTJsKDtqRXdNIjlc
QvvIIr/GRCg706+opff5WEKPZaTPscInO/Wgz6XB1VVCBzulxPjeJjvU2IAa
WctSQvWlBos8kyU7iCwm3UyzT0Ln6ohUuNkjO9KO4F9B/0lCxtm3zTKtITsq
qz1NmXhEQhIbfzCzER47LogR8u86PkIrUjtT6s8XOwb/GNIx2DNCsO8LSLyK
EDsPR1t+OYsjQhpM0HP+bwA7gDZzVw==
        "]]}}, {{}, {}}}, InsetBox[
     TemplateBox[{"\"Semi-classical Horbatsch Scaled\"", "\"Quantum\""},
      "PointLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 1]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 6}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.10666666666666666`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 6}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.10666666666666666`] -> 
                    Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0, 1, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0.5, 0, 0.5]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "6", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "6", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     Scaled[{0.8, 0.8}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox[
      "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
       HoldForm], TraditionalForm], 
     FormBox[
      TagBox["\"Power (Watts)\"", HoldForm], TraditionalForm]},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->{956., Automatic},
   Method->{
    "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
       Directive[
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.922526, 0.385626, 0.209179], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.528488, 0.470624, 0.701351], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.772079, 0.431554, 0.102387], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.363898, 0.618501, 0.782349], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[1, 0.75, 0], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.647624, 0.37816, 0.614037], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.571589, 0.586483, 0.], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.915, 0.3325, 0.2125], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
        AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
     "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
     "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotLabel->FormBox[
     StyleBox["\"Transition from n=100, l=50\"", 
      GrayLevel[0], StripOnInput -> False], TraditionalForm],
   PlotRange->{{0, 6.201238942785452*^12}, {0, 1.0100970086821574`*^-23}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.02], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{}, {{{
         Directive[
          PointSize[0.009166666666666668], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 1]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{
              EdgeForm[], 
              Disk[{0, 0}]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[0.009166666666666668], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 1]]}], {0., 0.}, Automatic, 
           Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM0F0ZNaj5ZC/iMG5xbQRTpn
YRLKVWSVQqwM1agJhFU6pv1UrGZKlELy/GKNRlBkOpNsXEZGQJNCWjwZRuFq
cjo8BH2hy0SSQj/dGQpuFYA66J7EhuhWkULApWVucyGLOjJm7aemdZBC1eYp
OJUnljpG8JxBSkCPQlsEld4ajqE6kFViiiyrjULbxF5ORg2rOioijGF7KoxC
iaLhHAZOtDoHu/cg3byKQkonaZymvr06hFODOxRhiUJlvwZ2M0vFOn5soor8
FYhCIhYd8jLXzToa5AroiNqGQh/aFA7/fdQ6lNsKCsGthUIhtvL+853bOjKV
Y5q/joRC/1Vn9d9H4joBZZ+AsHyDQmMzi5hQzOc6cAPJWc92gkJeVN9lIX7u
Ooy2NxhmfIFC84rgQXk+8zomadPGy4yAQqmIn+1U8vc61QKV18ZOf0J+9rnu
8WX9Ot3daQ42l31CWLrNZprQATt5Wx9V1fF7QkAdoOnuUwU7whm5TKddekKx
bc0McDwJO2lFC5e/2XhC1Mo7TuiGDTumw9h8QWV3QpFXKqOcFhE7QKCWs17/
dULExGk2GZMTO1SZkD9Wp3RCWXPv37wyFjtCfIpvc1xzQs8A2G/D7Rg7B9NN
7wweckK/s7ZB2LobO1rE3O6D63BCSEhWxiWPHjsK14a4hohvQsZ545w2ryA7
bgNzXH5PbUK0LDXUkg0iO/AB8HvnKmtCu5i9m1BbIzshpaRdyhlpQilfisGb
kCQ7g8OSxD0bZ0IYstTlOaUlO2Zu4u5lLmVCY3xgzqKQJjuoQ0Cpc1JjQqdI
dEUZSic7J8fydKOGYUJwR4rMw8gnOzMe9X15lF9CQrlKXsQDKDtrRXdNIjlc
QlyJnWBO8ic71q+opff5WEILzKSuuYsnO/Wgz6XB1VVCgSGmKpHHJjvY2IAa
WctSQhgyCEqanSU7iywm3UyzT0Izypjh0AUkO9mO4F9B/0lCWqXEcE34ITsx
qz1NmXhEQgGHJyv/2R47K4gR8u86PkKVSTy1B7YYOwf/GNIx2DNC5bTTgPBt
ETsfR1t+OYsjQtNGEyYqvQE7jpBuCg==
          "]]}, {
         Directive[
          PointSize[0.009166666666666668], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{
              EdgeForm[], 
              Polygon[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[0.009166666666666668], 
                AbsoluteThickness[1.6], 
                RGBColor[0.5, 0, 0.5]]}], {0., 0.}, Automatic, 
           Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM8F0ZNaj5ZCdScQQ/nmgTln
YRLKVWSVQlbY9kxYJ7w5pv1UrGZKlEKmR/68wULnOZRsXEZGQJNCmklkZU3h
Cjo7BH2hy0SSQpboddeYZig66Z7EhuhWkUJ6+FnPS4hCOjFm7aemdZBCSRbN
FQOAWDpF8JxBSkCPQmNf35Ov9Gw6j1ViiiyrjULXprPbJDF/OisijGF7KoxC
b+T5KA8TjzoIu/cg3byKQr0a+uVI9Jw6g1ODOxRhiUIV2V9rtnWpOn9soor8
FYhCwO4eDcZHtToc5AroiNqGQvSwy+86AsE6lNsKCsGthUIrJufy9SDKOjGV
Y5q/joRCrZfP1CBe0zoAZZ+AsHyDQlBPr5OWzts6cAPJWc92gkLemLWoOWTj
Ooy2NxhmfIFC2RAAc6BX6joladPGy4yAQlp51oR8d/E61QKV18ZOf0IEyrxF
UKj2Ot7daQ42l31ClBKzuJLM/Dp3Wx9V1fF7QvwMRW829gE7wxm5TKddekLE
XOtkcgQGO2lFC5e/2XhCOf+OiYuNCjunw9h8QWV3QlEjqwbbiQ87QKCWs17/
dUIg2oCBtHYSO1OZkD9Wp3RCo6IIefpTFTtCfIpvc1xzQr5bhgOQUhg7B9NN
7wweckLUzlwwW2YbO1rE3O6D63BCn24RQYmBHjsK14a4hohvQrHfkoFlyiA7
bgNzXH5PbUJgXOGKzEciO+0B8HvnKmtCkQSPsj6wIzshpaRdyhlpQs1XP5+v
+iQ7hMOSxD0bZ0IcWFbH5x0mO2du4u5lLmVCg8fijKkQJzuoQ0Cpc1JjQk8C
o1/UySc7J8fydKOGYUKiceQPhUAoOy8e9X15lF9CdepjmTJsKDtqRXdNIjlc
QvvIIr/GRCg706+opff5WEKPZaTPscInO/Wgz6XB1VVCBzulxPjeJjvU2IAa
WctSQvWlBos8kyU7iCwm3UyzT0Ln6ohUuNkjO9KO4F9B/0lCxtm3zTKtITsq
qz1NmXhEQhIbfzCzER47LogR8u86PkIrUjtT6s8XOwb/GNIx2DNCsO8LSLyK
EDsPR1t+OYsjQhpM0HP+bwA7gDZzVw==
          "]]}}}, {{}, {}}}, {
     DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
      GoldenRatio^(-1), Axes -> {True, True}, AxesLabel -> {
        HoldForm["Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))"], 
        HoldForm["Power (Watts)"]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
      Identity, Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}}, PlotLabel -> 
      Style["Transition from n=100, l=50", 
        GrayLevel[0]], 
      PlotRange -> {{0, 6.201238942785452*^12}, {
        0, 1.0100970086821574`*^-23}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      PointLegend[{
        Directive[
         PointSize[0.009166666666666668], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 1, 1]], 
        Directive[
         PointSize[0.009166666666666668], 
         AbsoluteThickness[1.6], 
         RGBColor[0.5, 0, 0.5]]}, {
       "Semi-classical Horbatsch Scaled", "Quantum"}, LegendMarkers -> {{
          Graphics[{
            EdgeForm[], 
            Disk[{0, 0}]}], 
          Offset[6]}, {
          Graphics[{
            EdgeForm[], 
            Polygon[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
          Offset[6]}}, Joined -> {False, False}, LabelStyle -> {}, 
       LegendLayout -> "Column"]], {0.8, 0.8}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.900150954284916*^9, 3.900150967105203*^9}, {
   3.900151050246385*^9, 3.9001510516851716`*^9}, 3.900151097188639*^9, 
   3.9001516986437483`*^9, 3.900154773695851*^9, 3.900164082619924*^9, 
   3.9001641868852572`*^9, {3.900164793903536*^9, 3.900164803595229*^9}},
 CellLabel->
  "Out[361]=",ExpressionUUID->"7f10081a-ce42-4010-9f2f-a1a6ca83d4f0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Binned Sums vs Semi-Classical Horbatsch vs Semi-Classical Horbatsch Scaled vs \
Quantum\
\>", "Section",
 CellChangeTimes->{{3.900065624568491*^9, 3.9000656325699906`*^9}, {
   3.9000681261502323`*^9, 3.9000681417502966`*^9}, {3.900150509960253*^9, 
   3.900150511792698*^9}, 3.9001508503358097`*^9},
 Background->GrayLevel[
  0.85],ExpressionUUID->"58305274-f6ea-4048-ac56-0e2e08a531d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"horbatsch", "'"}], "s", " ", "semi"}], "-", 
    RowBox[{"classical", " ", "approach"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"j", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["n", "2"], "*", 
       RowBox[{"(", 
        RowBox[{"4", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"]}], ")"}], "*", 
       SuperscriptBox["\[HBar]", "2"]}], 
      RowBox[{"m", "*", 
       SuperscriptBox["e", "2"]}]]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"Definition", " ", "for", " ", "a"}], "*)"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "0"], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["n", "3"]], "*", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"m", "*", 
         SuperscriptBox["e", "4"]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "*", "\[Pi]", "*", 
            SubscriptBox["\[Epsilon]", "0"]}], ")"}], "2"], "*", 
         SuperscriptBox["\[HBar]", "3"]}]], ")"}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"angular", " ", "frequency", " ", "reduction"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"frequency", " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "0"], "*", "k"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"maxK", "=", 
     FractionBox[
      RowBox[{"N", "[", 
       RowBox[{"R", "*", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n", "^", "2"}], ")"}]], "-", 
           RowBox[{"(", 
            FractionBox[
             RowBox[{"-", "1"}], 
             RowBox[{"(", 
              RowBox[{"l", "^", "2"}], ")"}]], ")"}]}], ")"}], "\[HBar]"]}], 
       "]"}], 
      SubscriptBox["\[Omega]", "0"]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"upTrans", "[", "k_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["j", "2"], "*", 
        SuperscriptBox["e", "2"], "*", 
        SuperscriptBox[
         SubscriptBox["\[Omega]", "0"], "3"], "*", "k"}], 
       RowBox[{
        RowBox[{"6", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", 
         SuperscriptBox["c", "3"]}], "\[IndentingNewLine]"}]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{"1", "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}], 
         "-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", 
               SuperscriptBox["\[Epsilon]", "2"]}], 
              SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"BesselJ", "[", 
             RowBox[{"k", ",", 
              RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], 
        ")"}], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"downTrans", "[", "k_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["j", "2"], "*", 
        SuperscriptBox["e", "2"], "*", 
        SuperscriptBox[
         SubscriptBox["\[Omega]", "0"], "3"], "*", "k"}], 
       RowBox[{
        RowBox[{"6", "*", "\[Pi]", "*", 
         SubscriptBox["\[Epsilon]", "0"], "*", "\[HBar]", "*", 
         SuperscriptBox["c", "3"]}], "\[IndentingNewLine]"}]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
             RowBox[{"BesselJ", "[", 
              RowBox[{
               RowBox[{"1", "+", "k"}], ",", 
               RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}], 
         "+", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"1", "-", 
               SuperscriptBox["\[Epsilon]", "2"]}], 
              SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"BesselJ", "[", 
             RowBox[{"k", ",", 
              RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], 
        ")"}], "2"]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerSemiClassicalHorbatschData", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"frequency", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"upTrans", "[", "k", "]"}], "+", 
            RowBox[{"downTrans", "[", "k", "]"}]}], ")"}], "*", "\[HBar]", 
          "*", "frequency"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "maxK"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Jasper", " ", "Quantum", " ", "approach"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dif", "[", 
      RowBox[{"n_", ",", " ", "n\[Prime]_", ",", " ", "l_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{"n\[Prime]", " ", "==", "n"}], ",", " ", 
       RowBox[{
        RowBox[{"output", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.5", "*", "n", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"n", "^", "2"}], " ", "-", " ", 
               RowBox[{"l", "^", "2"}]}], ")"}], "^", 
             RowBox[{"(", "0.5", ")"}]}]}], ")"}], "^", 
          RowBox[{"(", "2", ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"IntegerPart", "[", "output", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"output", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], 
            RowBox[{"(", 
             RowBox[{"4", "*", 
              RowBox[{"Factorial", "[", 
               RowBox[{
                RowBox[{"2", "*", "l"}], "-", "1"}], "]"}]}], ")"}]], "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"Factorial", "[", 
              RowBox[{"n", "+", "l"}], "]"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Factorial", "[", 
                RowBox[{"n\[Prime]", "+", "l", "-", "1"}], "]"}], "/", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Factorial", "[", 
                  RowBox[{"n", "-", "l", "-", "1"}], "]"}], "*", 
                 RowBox[{"Factorial", "[", 
                  RowBox[{"n\[Prime]", "-", "l"}], "]"}]}], ")"}]}], ")"}]}], 
            "]"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"n", "+", "n\[Prime]", "-", 
                  RowBox[{"2", "*", "l"}], "-", "2"}], ")"}]}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "*", "n", "*", "n\[Prime]"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"l", "+", "1"}], ")"}]}]}], ")"}], "/", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"n", "+", "n\[Prime]"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"n", "+", "n\[Prime]"}], ")"}]}]}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Hypergeometric2F1", "[", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], ",", 
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
               RowBox[{"2", "*", "l"}], ",", 
               FractionBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
              "]"}], "-", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                FractionBox[
                 RowBox[{"(", 
                  RowBox[{"n", "-", "n\[Prime]"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"n", "+", "n\[Prime]"}], ")"}]], ")"}], "^", "2"}], 
              "*", 
              RowBox[{"Hypergeometric2F1", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"n", "-", "l", "-", "1"}], ")"}]}], "-", "2"}], 
                ",", 
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{"n\[Prime]", "-", "l"}], ")"}]}], ",", 
                RowBox[{"2", "*", "l"}], ",", 
                FractionBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "*", "n", "*", "n\[Prime]"}], ")"}], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"n", "-", "n\[Prime]"}], ")"}], "^", "2"}]]}], 
               "]"}]}]}], ")"}]}], ")"}], "^", "2"}]}]}], "]"}]}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"getOmega", "[", 
      RowBox[{"n_", ",", "n\[Prime]_"}], "]"}], "=", 
     RowBox[{"N", "[", 
      RowBox[{"R", "*", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "1"}], 
           RowBox[{"(", 
            RowBox[{"n", "^", "2"}], ")"}]], "-", 
          RowBox[{"(", 
           FractionBox[
            RowBox[{"-", "1"}], 
            RowBox[{"(", 
             RowBox[{"n\[Prime]", "^", "2"}], ")"}]], ")"}]}], ")"}], 
        "\[HBar]"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"powerQuantumApproach", "[", 
      RowBox[{
      "\[Omega]_", ",", "n_", ",", "n\[Prime]_", ",", "l_", ",", 
       "l\[Prime]_"}], "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"(", 
        RowBox[{"\[HBar]", "*", 
         RowBox[{"\[Omega]", "^", "4"}], "*", 
         RowBox[{"Max", "[", 
          RowBox[{"l", ",", "l\[Prime]"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"3", 
         RowBox[{"\[Pi]", "^", "3"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "l"}], "+", "1"}], ")"}], "*", 
         RowBox[{"Ry", "^", "3"}]}], ")"}]], "*", 
      RowBox[{"dif", "[", 
       RowBox[{"n", ",", "n\[Prime]", ",", "l"}], "]"}], "*", 
      RowBox[{"10", "^", "9"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerQuantumData", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"getOmega", "[", 
          RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", 
         RowBox[{"powerQuantumApproach", "[", 
          RowBox[{
           RowBox[{"getOmega", "[", 
            RowBox[{"n", ",", "n\[Prime]"}], "]"}], ",", "n", ",", 
           "n\[Prime]", ",", "l", ",", 
           RowBox[{"l", "-", "1"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n\[Prime]", ",", "l", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Horbatsch", " ", "semi", " ", "classical", " ", "approach", " ", 
     "scaled"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"kScaler", "[", "nPrime_", "]"}], " ", ":=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"n", "-", "nPrime"}], ")"}], "/", "n"}]}], ")"}], 
      RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"omegaQuantum", "[", "nPrime_", "]"}], " ", ":=", " ", 
     RowBox[{"R", "*", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], 
         SuperscriptBox["n", "2"]], "-", 
        FractionBox[
         RowBox[{"-", "1"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"n", "-", 
            RowBox[{"(", 
             RowBox[{"n", "-", "nPrime"}], ")"}]}], ")"}], "2"]]}], 
       "\[HBar]"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"harmonicK", "[", "nPrime_", "]"}], ":=", " ", 
     RowBox[{
      FractionBox["n", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"n", "-", "nPrime"}], ")"}], "/", "n"}]}], ")"}], 
         RowBox[{"-", "2"}]], "-", "1"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"powerSemiClassicalHorbatschScaledData", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"omegaQuantum", "[", "nPrime", "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"upTrans", "[", " ", 
             RowBox[{"harmonicK", "[", "nPrime", "]"}], "]"}], "+", 
            RowBox[{"downTrans", "[", " ", 
             RowBox[{"harmonicK", "[", "nPrime", "]"}], "]"}]}], ")"}], "*", 
          "\[HBar]", "*", 
          RowBox[{"kScaler", "[", "nPrime", "]"}], "*", 
          RowBox[{"omegaQuantum", "[", "nPrime", "]"}]}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"nPrime", ",", "l", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "binning", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"binLocations", "=", 
     RowBox[{"MovingAverage", "[", 
      RowBox[{
       RowBox[{"powerSemiClassicalHorbatschScaledData", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "2"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"powerSemiClassicalHorbatschData", ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"binSums", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"Length", "[", "binLocations", "]"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"binLocations", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<-\>\"", ",", 
        RowBox[{"binLocations", "[", 
         RowBox[{"[", 
          RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], "*)"}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"binSum", "=", "0"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "<", 
          RowBox[{"Length", "[", 
           RowBox[{"powerSemiClassicalHorbatschData", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"powerSemiClassicalHorbatschData", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], "<", 
             RowBox[{"binLocations", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"powerSemiClassicalHorbatschData", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], ">", 
             RowBox[{"binLocations", "[", 
              RowBox[{"[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}]}]}], ",", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"binSum", "=", 
             RowBox[{"binSum", "+", 
              RowBox[{"powerSemiClassicalHorbatschData", "[", 
               RowBox[{"[", 
                RowBox[{"j", ",", "2"}], "]"}], "]"}]}]}], ";"}]}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"Print", "[", 
            RowBox[{"powerSemiClassicalHorbatschData", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}], "*)"}], 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"binSums", ",", "binSum"}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"binSums", ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"binnedSumsPlot", "=", 
     RowBox[{"Transpose", "@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"powerSemiClassicalHorbatschScaledData", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"2", ";;", 
           RowBox[{
            RowBox[{"Length", "[", "binSums", "]"}], "+", "1"}]}], "]"}], 
         "]"}], ",", "binSums"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "binnedSumsPlot", ",", "powerSemiClassicalHorbatschData", ",", 
       "powerSemiClassicalHorbatschScaledData", ",", "powerQuantumData"}], 
      "}"}], ",", 
     RowBox[{"PlotLegends", "->", 
      RowBox[{"Placed", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<Binned Sums\>\"", ",", "\"\<Semi-classical Horbatsch\>\"", ",", 
          "\"\<Semi-classical Horbatsch Scaled\>\"", ",", "\"\<Quantum\>\""}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{".8", ",", ".8"}], "}"}]}], "]"}]}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"Cyan", ",", "Purple", ",", "Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotMarkers", "->", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "6"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))\>\"", ",", " ", 
        "\"\<Power (Watts)\>\""}], "}"}]}], ",", " ", 
     RowBox[{"PlotLabel", " ", "->", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
         "StringTemplate", "[", "\"\<Transition from n=`1`, l=`2`\>\"", "]"}],
          "[", 
         RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "->", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.9000656585195494`*^9, {3.9000656916540823`*^9, 3.900065722815731*^9}, 
   3.9000666541921625`*^9, {3.900067780768008*^9, 3.900067782718689*^9}, {
   3.900068164831855*^9, 3.900068168807623*^9}, {3.9000782778995867`*^9, 
   3.9000782792988415`*^9}, {3.9001494652743835`*^9, 3.9001495173189783`*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[362]:=",ExpressionUUID->"56008cac-2b24-4623-a857-93d4deddd90d"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{}, {
      {RGBColor[0, 1, 1], PointSize[0.007333333333333334], AbsoluteThickness[
       1.6], GeometricTransformationBox[InsetBox[
         FormBox[
          StyleBox[
           GraphicsBox[
            {EdgeForm[None], DiskBox[{0, 0}]}],
           StripOnInput->False,
           GraphicsBoxOptions->{DefaultBaseStyle->Directive[
             PointSize[0.007333333333333334], 
             AbsoluteThickness[1.6], 
             RGBColor[0, 1, 1]]}],
          TraditionalForm], {0., 0.}, Automatic, Offset[6]], CompressedData["
1:eJwBFQPq/CFib1JlAwAAADAAAAABAAAAAgAAAGdhEspVZJVCVdBaLVbKVjqm
/VSsZkqUQo+tSGRQLmQ6k2xcRkZAk0IFNr1mNIhzOjwEfaHLRJJCUZrDs7Kv
fjronsSG6FaRQiKLIxgv5Io6Mmbtp6Z1kEKysg63foCXOkbwnEFKQI9Cbjkf
a4I7oDqQVWKKLKuNQrnbsztjuqk6KiKMYXsqjEJ51Ve/Tla0Oge79yDdvIpC
NkWIqL4HwDqEU4M7FGGJQo6roYEqNcM6fmyiivwViEKm2TDQxYPLOhrkCuiI
2oZC+648M5qo0zqU2woKwa2FQhXamCawA9w6MpVjmr+OhEJ8bkVmcebjOgFl
n4CwfINCxInlbMQx5DpwA8lZz3aCQuQAqQB/PfI6jLY3GGZ8gUItow0qBmby
OiZp08bLjIBCKdsQgD6x9zrVApXXxk5/QiyADyU5a/463d1pDjaXfULAtqy0
cnYDO3lbH1XV8XtCxpFNKGe9/zrCGblMp116QnpplZDWGg07aUULl7/ZeEJh
kHN3FJcHO6bD2HxBZXdC/vTUaFF7FTtAoJazXv91QpDICbmeRxE7VJmQP1an
dEKJ+1BpDQgUO0J8im9zXHNCacNYSMskFzsH003vDB5yQp7ZwPaMoxo7WsTc
7oPrcEJnJml84YceOwrXhriGiG9CjtGVIfdoITtuA3Ncfk9tQgWJgBlaviM7
8AHwe+cqa0LzTl843D0mOyGlpF3KGWlC6lqk5N4xGDuDw5LEPRtnQs6Ihfbf
MCo7Zm7i7mUuZULY62GBNNYsO6hDQKlzUmNCKZmYaaW+Hjsnx/J0o4ZhQndK
BA+xPDA7Mx71fXmUX0I9CXzO4fsgO2tFd00iOVxCPTi8QNdeITvWr6il9/lY
Qshsi+V1tTE79aDPpcHVVULI0zPPVrohO9jYgBpZy1JCaNOUAgF3ITuLLCbd
TLNPQisGy4DbgzA72Y7gX0H/SUI0OjKsZrkdOzGrPU2ZeERCZoGkvkBXGjsr
iBHy7zo+QrOwNZB62BU7B/8Y0jHYM0LVFkzLwP8POwNcXrA=
        "]]}, 
      {RGBColor[0.5, 0, 0.5], PointSize[0.007333333333333334], 
       AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
         FormBox[
          StyleBox[
           GraphicsBox[
            {EdgeForm[None], 
             PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}],
           StripOnInput->False,
           GraphicsBoxOptions->{DefaultBaseStyle->Directive[
             PointSize[0.007333333333333334], 
             AbsoluteThickness[1.6], 
             RGBColor[0.5, 0, 0.5]]}],
          TraditionalForm], {0., 0.}, Automatic, Offset[6]], CompressedData["
1:eJw1lHk4lOsfxlFZWlCHkZzKkvqppLKk55X0tVR+JGQbssVkS8a+TBjL2AbD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        "]]}, 
      {RGBColor[0, 0, 1], PointSize[0.007333333333333334], AbsoluteThickness[
       1.6], GeometricTransformationBox[InsetBox[
         FormBox[
          StyleBox[
           GraphicsBox[
            {EdgeForm[None], PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}],
           StripOnInput->False,
           GraphicsBoxOptions->{DefaultBaseStyle->Directive[
             PointSize[0.007333333333333334], 
             AbsoluteThickness[1.6], 
             RGBColor[0, 0, 1]]}],
          TraditionalForm], {0., 0.}, Automatic, Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM0F0ZNaj5ZC/iMG5xbQRTpn
YRLKVWSVQqwM1agJhFU6pv1UrGZKlELy/GKNRlBkOpNsXEZGQJNCWjwZRuFq
cjo8BH2hy0SSQj/dGQpuFYA66J7EhuhWkULApWVucyGLOjJm7aemdZBC1eYp
OJUnljpG8JxBSkCPQlsEld4ajqE6kFViiiyrjULbxF5ORg2rOioijGF7KoxC
iaLhHAZOtDoHu/cg3byKQkonaZymvr06hFODOxRhiUJlvwZ2M0vFOn5soor8
FYhCIhYd8jLXzToa5AroiNqGQh/aFA7/fdQ6lNsKCsGthUIhtvL+853bOjKV
Y5q/joRC/1Vn9d9H4joBZZ+AsHyDQmMzi5hQzOc6cAPJWc92gkJeVN9lIX7u
Ooy2NxhmfIFC84rgQXk+8zomadPGy4yAQqmIn+1U8vc61QKV18ZOf0J+9rnu
8WX9Ot3daQ42l31CWLrNZprQATt5Wx9V1fF7QkAdoOnuUwU7whm5TKddekKx
bc0McDwJO2lFC5e/2XhC1Mo7TuiGDTumw9h8QWV3QpFXKqOcFhE7QKCWs17/
dULExGk2GZMTO1SZkD9Wp3RCWXPv37wyFjtCfIpvc1xzQs8A2G/D7Rg7B9NN
7wweckK/s7ZB2LobO1rE3O6D63BCSEhWxiWPHjsK14a4hohvQsZ545w2ryA7
bgNzXH5PbUK0LDXUkg0iO/AB8HvnKmtCu5i9m1BbIzshpaRdyhlpQilfisGb
kCQ7g8OSxD0bZ0IYstTlOaUlO2Zu4u5lLmVCY3xgzqKQJjuoQ0Cpc1JjQqdI
dEUZSic7J8fydKOGYUJwR4rMw8gnOzMe9X15lF9CQrlKXsQDKDtrRXdNIjlc
QlyJnWBO8ic71q+opff5WEILzKSuuYsnO/Wgz6XB1VVCgSGmKpHHJjvY2IAa
WctSQhgyCEqanSU7iywm3UyzT0Izypjh0AUkO9mO4F9B/0lCWqXEcE34ITsx
qz1NmXhEQgGHJyv/2R47K4gR8u86PkKVSTy1B7YYOwf/GNIx2DNC5bTTgPBt
ETsfR1t+OYsjQtNGEyYqvQE7jpBuCg==
        "]]}, 
      {RGBColor[1, 0, 0], PointSize[0.007333333333333334], AbsoluteThickness[
       1.6], GeometricTransformationBox[InsetBox[
         FormBox[
          StyleBox[
           GraphicsBox[
            {EdgeForm[None], 
             PolygonBox[
              NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                1, 1 - 3^Rational[1, 2]}}, {{0, 
                1}, {-1, -0.7320508075688772}, {1, -0.7320508075688772}}]]}],
           StripOnInput->False,
           GraphicsBoxOptions->{DefaultBaseStyle->Directive[
             PointSize[0.007333333333333334], 
             AbsoluteThickness[1.6], 
             RGBColor[1, 0, 0]]}],
          TraditionalForm], {0., 0.}, Automatic, Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM8F0ZNaj5ZCdScQQ/nmgTln
YRLKVWSVQlbY9kxYJ7w5pv1UrGZKlEKmR/68wULnOZRsXEZGQJNCmklkZU3h
Cjo7BH2hy0SSQpboddeYZig66Z7EhuhWkUJ6+FnPS4hCOjFm7aemdZBCSRbN
FQOAWDpF8JxBSkCPQmNf35Ov9Gw6j1ViiiyrjULXprPbJDF/OisijGF7KoxC
b+T5KA8TjzoIu/cg3byKQr0a+uVI9Jw6g1ODOxRhiUIV2V9rtnWpOn9soor8
FYhCwO4eDcZHtToc5AroiNqGQvSwy+86AsE6lNsKCsGthUIrJufy9SDKOjGV
Y5q/joRCrZfP1CBe0zoAZZ+AsHyDQlBPr5OWzts6cAPJWc92gkLemLWoOWTj
Ooy2NxhmfIFC2RAAc6BX6joladPGy4yAQlp51oR8d/E61QKV18ZOf0IEyrxF
UKj2Ot7daQ42l31ClBKzuJLM/Dp3Wx9V1fF7QvwMRW829gE7wxm5TKddekLE
XOtkcgQGO2lFC5e/2XhCOf+OiYuNCjunw9h8QWV3QlEjqwbbiQ87QKCWs17/
dUIg2oCBtHYSO1OZkD9Wp3RCo6IIefpTFTtCfIpvc1xzQr5bhgOQUhg7B9NN
7wweckLUzlwwW2YbO1rE3O6D63BCn24RQYmBHjsK14a4hohvQrHfkoFlyiA7
bgNzXH5PbUJgXOGKzEciO+0B8HvnKmtCkQSPsj6wIzshpaRdyhlpQs1XP5+v
+iQ7hMOSxD0bZ0IcWFbH5x0mO2du4u5lLmVCg8fijKkQJzuoQ0Cpc1JjQk8C
o1/UySc7J8fydKOGYUKiceQPhUAoOy8e9X15lF9CdepjmTJsKDtqRXdNIjlc
QvvIIr/GRCg706+opff5WEKPZaTPscInO/Wgz6XB1VVCBzulxPjeJjvU2IAa
WctSQvWlBos8kyU7iCwm3UyzT0Ln6ohUuNkjO9KO4F9B/0lCxtm3zTKtITsq
qz1NmXhEQhIbfzCzER47LogR8u86PkIrUjtT6s8XOwb/GNIx2DNCsO8LSLyK
EDsPR1t+OYsjQhpM0HP+bwA7gDZzVw==
        "]]}}, {{}, {}}}, InsetBox[
     TemplateBox[{
      "\"Binned Sums\"", "\"Semi-classical Horbatsch\"", 
       "\"Semi-classical Horbatsch Scaled\"", "\"Quantum\""},
      "PointLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 1]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}, {DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 6}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.10666666666666666`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.5, 0, 0.5]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 6}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.10666666666666666`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 6}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.10666666666666666`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    InsetBox[
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}, {
                    DefaultBaseStyle -> {"Graphics", {
                    AbsolutePointSize[6]}, 
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]]}}], 
                    NCache[
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}], 
                    Scaled[{0.5, 0.5}]], Automatic, 
                    Scaled[1]]}}}, AspectRatio -> Full, ImageSize -> {10, 6}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[-0.10666666666666666`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   TemplateBox[<|"color" -> RGBColor[0, 1, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0.5, 0, 0.5]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0, 0, 1]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.007333333333333334`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[1, 0, 0]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    DiskBox[{0, 0}]}], ",", 
                    RowBox[{"Offset", "[", "6", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], ",", 
                    RowBox[{"Offset", "[", "6", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], ",", 
                    RowBox[{"Offset", "[", "6", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{
                    GraphicsBox[{
                    EdgeForm[], 
                    PolygonBox[
                    
                    NCache[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                    1, 1 - 3^Rational[1, 2]}}, {{0, 
                    1}, {-1, -0.7320508075688772}, {
                    1, -0.7320508075688772}}]]}], ",", 
                    RowBox[{"Offset", "[", "6", "]"}]}], "}"}]}], "}"}]}], 
           ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False", ",", "False", ",", "False"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     Scaled[{0.8, 0.8}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{
     FormBox[
      TagBox[
      "\"Frequency(\\!\\(\\*FractionBox[\\(rad\\), \\(sec\\)]\\))\"", 
       HoldForm], TraditionalForm], 
     FormBox[
      TagBox["\"Power (Watts)\"", HoldForm], TraditionalForm]},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImageSize->{672., Automatic},
   Method->{
    "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
       Directive[
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.922526, 0.385626, 0.209179], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.528488, 0.470624, 0.701351], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.772079, 0.431554, 0.102387], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.363898, 0.618501, 0.782349], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[1, 0.75, 0], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.647624, 0.37816, 0.614037], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.571589, 0.586483, 0.], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.915, 0.3325, 0.2125], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
        AbsoluteThickness[1.6]], 
       Directive[
        RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
        AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
     "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
     "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Identity[
          Part[#, 1]], 
         Identity[
          Part[#, 2]]}& )}},
   PlotLabel->FormBox[
     StyleBox["\"Transition from n=100, l=50\"", 
      GrayLevel[0], StripOnInput -> False], TraditionalForm],
   PlotRange->{{0, 6.201238942785452*^12}, {0, 1.4648401020909147`*^-23}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.02], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{}, {{{
         Directive[
          PointSize[0.007333333333333334], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 1, 1]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{
              EdgeForm[], 
              Disk[{0, 0}]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 1, 1]]}], {0., 0.}, Automatic, 
           Offset[6]], CompressedData["
1:eJwBFQPq/CFib1JlAwAAADAAAAABAAAAAgAAAGdhEspVZJVCVdBaLVbKVjqm
/VSsZkqUQo+tSGRQLmQ6k2xcRkZAk0IFNr1mNIhzOjwEfaHLRJJCUZrDs7Kv
fjronsSG6FaRQiKLIxgv5Io6Mmbtp6Z1kEKysg63foCXOkbwnEFKQI9Cbjkf
a4I7oDqQVWKKLKuNQrnbsztjuqk6KiKMYXsqjEJ51Ve/Tla0Oge79yDdvIpC
NkWIqL4HwDqEU4M7FGGJQo6roYEqNcM6fmyiivwViEKm2TDQxYPLOhrkCuiI
2oZC+648M5qo0zqU2woKwa2FQhXamCawA9w6MpVjmr+OhEJ8bkVmcebjOgFl
n4CwfINCxInlbMQx5DpwA8lZz3aCQuQAqQB/PfI6jLY3GGZ8gUItow0qBmby
OiZp08bLjIBCKdsQgD6x9zrVApXXxk5/QiyADyU5a/463d1pDjaXfULAtqy0
cnYDO3lbH1XV8XtCxpFNKGe9/zrCGblMp116QnpplZDWGg07aUULl7/ZeEJh
kHN3FJcHO6bD2HxBZXdC/vTUaFF7FTtAoJazXv91QpDICbmeRxE7VJmQP1an
dEKJ+1BpDQgUO0J8im9zXHNCacNYSMskFzsH003vDB5yQp7ZwPaMoxo7WsTc
7oPrcEJnJml84YceOwrXhriGiG9CjtGVIfdoITtuA3Ncfk9tQgWJgBlaviM7
8AHwe+cqa0LzTl843D0mOyGlpF3KGWlC6lqk5N4xGDuDw5LEPRtnQs6Ihfbf
MCo7Zm7i7mUuZULY62GBNNYsO6hDQKlzUmNCKZmYaaW+Hjsnx/J0o4ZhQndK
BA+xPDA7Mx71fXmUX0I9CXzO4fsgO2tFd00iOVxCPTi8QNdeITvWr6il9/lY
Qshsi+V1tTE79aDPpcHVVULI0zPPVrohO9jYgBpZy1JCaNOUAgF3ITuLLCbd
TLNPQisGy4DbgzA72Y7gX0H/SUI0OjKsZrkdOzGrPU2ZeERCZoGkvkBXGjsr
iBHy7zo+QrOwNZB62BU7B/8Y0jHYM0LVFkzLwP8POwNcXrA=
          "]]}, {
         Directive[
          PointSize[0.007333333333333334], 
          AbsoluteThickness[1.6], 
          RGBColor[0.5, 0, 0.5]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{
              EdgeForm[], 
              Polygon[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0.5, 0, 0.5]]}], {0., 0.}, Automatic, 
           Offset[6]], CompressedData["
1:eJw1lHk4lOsfxlFZWlCHkZzKkvqppLKk55X0tVR+JGQbssVkS8a+TBjL2AbD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          "]]}, {
         Directive[
          PointSize[0.007333333333333334], 
          AbsoluteThickness[1.6], 
          RGBColor[0, 0, 1]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{
              EdgeForm[], 
              Polygon[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[0, 0, 1]]}], {0., 0.}, Automatic, 
           Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM0F0ZNaj5ZC/iMG5xbQRTpn
YRLKVWSVQqwM1agJhFU6pv1UrGZKlELy/GKNRlBkOpNsXEZGQJNCWjwZRuFq
cjo8BH2hy0SSQj/dGQpuFYA66J7EhuhWkULApWVucyGLOjJm7aemdZBC1eYp
OJUnljpG8JxBSkCPQlsEld4ajqE6kFViiiyrjULbxF5ORg2rOioijGF7KoxC
iaLhHAZOtDoHu/cg3byKQkonaZymvr06hFODOxRhiUJlvwZ2M0vFOn5soor8
FYhCIhYd8jLXzToa5AroiNqGQh/aFA7/fdQ6lNsKCsGthUIhtvL+853bOjKV
Y5q/joRC/1Vn9d9H4joBZZ+AsHyDQmMzi5hQzOc6cAPJWc92gkJeVN9lIX7u
Ooy2NxhmfIFC84rgQXk+8zomadPGy4yAQqmIn+1U8vc61QKV18ZOf0J+9rnu
8WX9Ot3daQ42l31CWLrNZprQATt5Wx9V1fF7QkAdoOnuUwU7whm5TKddekKx
bc0McDwJO2lFC5e/2XhC1Mo7TuiGDTumw9h8QWV3QpFXKqOcFhE7QKCWs17/
dULExGk2GZMTO1SZkD9Wp3RCWXPv37wyFjtCfIpvc1xzQs8A2G/D7Rg7B9NN
7wweckK/s7ZB2LobO1rE3O6D63BCSEhWxiWPHjsK14a4hohvQsZ545w2ryA7
bgNzXH5PbUK0LDXUkg0iO/AB8HvnKmtCu5i9m1BbIzshpaRdyhlpQilfisGb
kCQ7g8OSxD0bZ0IYstTlOaUlO2Zu4u5lLmVCY3xgzqKQJjuoQ0Cpc1JjQqdI
dEUZSic7J8fydKOGYUJwR4rMw8gnOzMe9X15lF9CQrlKXsQDKDtrRXdNIjlc
QlyJnWBO8ic71q+opff5WEILzKSuuYsnO/Wgz6XB1VVCgSGmKpHHJjvY2IAa
WctSQhgyCEqanSU7iywm3UyzT0Izypjh0AUkO9mO4F9B/0lCWqXEcE34ITsx
qz1NmXhEQgGHJyv/2R47K4gR8u86PkKVSTy1B7YYOwf/GNIx2DNC5bTTgPBt
ETsfR1t+OYsjQtNGEyYqvQE7jpBuCg==
          "]]}, {
         Directive[
          PointSize[0.007333333333333334], 
          AbsoluteThickness[1.6], 
          RGBColor[1, 0, 0]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{
              EdgeForm[], 
              
              Polygon[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
                1, 1 - 3^Rational[1, 2]}}]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[0.007333333333333334], 
                AbsoluteThickness[1.6], 
                RGBColor[1, 0, 0]]}], {0., 0.}, Automatic, 
           Offset[6]], CompressedData["
1:eJwBNQPK/CFib1JlAwAAADIAAAABAAAAAgAAAM8F0ZNaj5ZCdScQQ/nmgTln
YRLKVWSVQlbY9kxYJ7w5pv1UrGZKlEKmR/68wULnOZRsXEZGQJNCmklkZU3h
Cjo7BH2hy0SSQpboddeYZig66Z7EhuhWkUJ6+FnPS4hCOjFm7aemdZBCSRbN
FQOAWDpF8JxBSkCPQmNf35Ov9Gw6j1ViiiyrjULXprPbJDF/OisijGF7KoxC
b+T5KA8TjzoIu/cg3byKQr0a+uVI9Jw6g1ODOxRhiUIV2V9rtnWpOn9soor8
FYhCwO4eDcZHtToc5AroiNqGQvSwy+86AsE6lNsKCsGthUIrJufy9SDKOjGV
Y5q/joRCrZfP1CBe0zoAZZ+AsHyDQlBPr5OWzts6cAPJWc92gkLemLWoOWTj
Ooy2NxhmfIFC2RAAc6BX6joladPGy4yAQlp51oR8d/E61QKV18ZOf0IEyrxF
UKj2Ot7daQ42l31ClBKzuJLM/Dp3Wx9V1fF7QvwMRW829gE7wxm5TKddekLE
XOtkcgQGO2lFC5e/2XhCOf+OiYuNCjunw9h8QWV3QlEjqwbbiQ87QKCWs17/
dUIg2oCBtHYSO1OZkD9Wp3RCo6IIefpTFTtCfIpvc1xzQr5bhgOQUhg7B9NN
7wweckLUzlwwW2YbO1rE3O6D63BCn24RQYmBHjsK14a4hohvQrHfkoFlyiA7
bgNzXH5PbUJgXOGKzEciO+0B8HvnKmtCkQSPsj6wIzshpaRdyhlpQs1XP5+v
+iQ7hMOSxD0bZ0IcWFbH5x0mO2du4u5lLmVCg8fijKkQJzuoQ0Cpc1JjQk8C
o1/UySc7J8fydKOGYUKiceQPhUAoOy8e9X15lF9CdepjmTJsKDtqRXdNIjlc
QvvIIr/GRCg706+opff5WEKPZaTPscInO/Wgz6XB1VVCBzulxPjeJjvU2IAa
WctSQvWlBos8kyU7iCwm3UyzT0Ln6ohUuNkjO9KO4F9B/0lCxtm3zTKtITsq
qz1NmXhEQhIbfzCzER47LogR8u86PkIrUjtT6s8XOwb/GNIx2DNCsO8LSLyK
EDsPR1t+OYsjQhpM0HP+bwA7gDZzVw==
          "]]}}}, {{}, {}}}, {
     DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
      GoldenRatio^(-1), Axes -> {True, True}, AxesLabel -> {
        HoldForm["Frequency(\!\(\*FractionBox[\(rad\), \(sec\)]\))"], 
        HoldForm["Power (Watts)"]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
      Identity, Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          Directive[
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
        "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> 
        Scaled[0.05], "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> 
        True, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& )}}, PlotLabel -> 
      Style["Transition from n=100, l=50", 
        GrayLevel[0]], 
      PlotRange -> {{0, 6.201238942785452*^12}, {
        0, 1.4648401020909147`*^-23}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      PointLegend[{
        Directive[
         PointSize[0.007333333333333334], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 1, 1]], 
        Directive[
         PointSize[0.007333333333333334], 
         AbsoluteThickness[1.6], 
         RGBColor[0.5, 0, 0.5]], 
        Directive[
         PointSize[0.007333333333333334], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 0, 1]], 
        Directive[
         PointSize[0.007333333333333334], 
         AbsoluteThickness[1.6], 
         RGBColor[1, 0, 0]]}, {
       "Binned Sums", "Semi-classical Horbatsch", 
        "Semi-classical Horbatsch Scaled", "Quantum"}, LegendMarkers -> {{
          Graphics[{
            EdgeForm[], 
            Disk[{0, 0}]}], 
          Offset[6]}, {
          Graphics[{
            EdgeForm[], 
            Polygon[{{-1, -1}, {1, -1}, {1, 1}, {-1, 1}}]}], 
          Offset[6]}, {
          Graphics[{
            EdgeForm[], 
            Polygon[{{0, 1}, {1, 0}, {0, -1}, {-1, 0}}]}], 
          Offset[6]}, {
          Graphics[{
            EdgeForm[], 
            
            Polygon[{{0, 1}, {-1, 1 - 3^Rational[1, 2]}, {
              1, 1 - 3^Rational[1, 2]}}]}], 
          Offset[6]}}, Joined -> {False, False, False, False}, 
       LabelStyle -> {}, LegendLayout -> "Column"]], {0.8, 0.8}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.900065697064736*^9, 3.90006573865602*^9}, {
   3.9000657827066774`*^9, 3.900065786971423*^9}, {3.9000659562004566`*^9, 
   3.90006595984636*^9}, {3.900067245186166*^9, 3.9000672514007072`*^9}, 
   3.900068036056184*^9, 3.90007712979191*^9, 3.9000783574404554`*^9, 
   3.9000815393463573`*^9, {3.9000819131723504`*^9, 3.9000819475195236`*^9}, {
   3.9001489501391444`*^9, 3.900148958771119*^9}, {3.9001495191639223`*^9, 
   3.900149532156667*^9}, 3.9001509618125615`*^9, 3.900164083289618*^9, {
   3.9001647945551195`*^9, 3.900164804054984*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "Out[383]=",ExpressionUUID->"d6b8c612-18a2-4dcf-bdeb-7ed88abec87e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Elliptical", " ", "Orbit", " ", "Animation"}]], "Section",
 CellChangeTimes->{
  3.900065830220359*^9, 3.9000658867275352`*^9, {3.9000659678675656`*^9, 
   3.9000659747833586`*^9}, {3.90006611505613*^9, 3.900066119899681*^9}},
 Background->GrayLevel[
  0.85],ExpressionUUID->"ef6a2437-4488-4d6d-840b-60af19a1a84f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    SubscriptBox["a", "0"], " ", "is", " ", "semimajor", " ", "axis"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"coef1", " ", "=", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "+", "k"}], ",", 
           RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], "-", 
         RowBox[{"BesselJ", "[", 
          RowBox[{
           RowBox[{"1", "+", "k"}], ",", 
           RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}]}], ")"}]}], ")"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coef2", "=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", 
           SuperscriptBox["\[Epsilon]", "2"]}], 
          SuperscriptBox["\[Epsilon]", "2"]], ")"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"BesselJ", "[", 
         RowBox[{"k", ",", 
          RowBox[{"k", "*", "\[Epsilon]"}]}], "]"}], ")"}]}], ")"}]}], ";"}], 
   " ", 
   RowBox[{"(*", 
    RowBox[{
    "bessel", " ", "functions", " ", "used", " ", "in", " ", "Horbatsch", " ",
      "paper", " ", "parameterization", " ", "of", " ", "ellipse"}], "*)"}], 
   " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "0"], "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Alpha]", "2"], "*", "m", "*", 
       SuperscriptBox["c", "2"]}], 
      RowBox[{"(", 
       RowBox[{"\[HBar]", "*", 
        RowBox[{"n", "^", "3"}]}], ")"}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xx", " ", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"-", "3"}], "2"], "*", "\[Epsilon]", "*", 
       SubscriptBox["a", "0"]}], "+", 
      RowBox[{"Sum", "[", " ", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"2", "*", 
           SubscriptBox["a", "0"]}], "k"], "*", "coef1", "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"k", "*", 
           SubscriptBox["\[Omega]", "0"], "*", "t"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "100"}], "]"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yy", " ", "=", " ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"2", "*", 
          SubscriptBox["a", "0"]}], "k"], "*", "coef2", "*", 
        RowBox[{"Sin", "[", 
         RowBox[{"k", "*", 
          SubscriptBox["\[Omega]", "0"], "*", "t"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "100"}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"focus", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"-", "3"}], "2"], "*", "\[Epsilon]", "*", 
       SubscriptBox["a", "0"]}], "+", 
      RowBox[{"Sum", "[", " ", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"2", "*", 
           SubscriptBox["a", "0"]}], "k"], "*", "coef1"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "100"}], "]"}]}], "}"}]}], "]"}], "-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["a", "0"], "-", 
        RowBox[{"\[Epsilon]", "*", 
         SubscriptBox["a", "0"]}]}], ")"}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"should", " ", "equal", " ", "zero"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"orbit", "=", 
    RowBox[{
     RowBox[{
     "ResourceFunction", "[", "\"\<ManipulateParametricPlot\>\"", "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xx", ",", "yy"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", ".000000001", ",", ".000000000001"}], 
       "}"}], ",", 
      RowBox[{"\"\<DrawVector\>\"", "->", "False"}], ",", 
      RowBox[{"SaveDefinitions", "->", "True"}], ",", 
      RowBox[{"PlotLabel", " ", "->", 
       RowBox[{"Style", "[", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
          "StringTemplate", "[", 
           "\"\<Elliptical Orbit of Electron with n=`1`, l=`2`\>\"", "]"}], 
          "[", 
          RowBox[{"n", ",", "l"}], "]"}], ",", "Black"}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Click", " ", "the", " ", "plus", " ", "button", " ", "to", " ", "play", 
     " ", "the", " ", "animation"}], "*)"}]}]}]], "Input",
 CellChangeTimes->{
  3.900066125032843*^9, {3.9000672620042257`*^9, 3.9000672685638657`*^9}, {
   3.9000673798366127`*^9, 3.900067394284461*^9}, 3.900067631533643*^9, {
   3.9000678111936398`*^9, 3.9000678564026885`*^9}, {3.9001648246404*^9, 
   3.900164839186366*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "In[391]:=",ExpressionUUID->"58387c4c-1456-4613-a4aa-53e256abbe93"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{
    FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`k$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`k$$], 0, 
       "Parameter"}, 0, 1.*^-9, 1.*^-12}}, Typeset`size$$ = {
    360., {94., 97.74749964702971}}, Typeset`update$$ = 0, Typeset`initDone$$,
     Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {
       FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`k$$ = 0}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Show[FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`plot$33207, 
        Graphics[
         Flatten[
          MapThread[{#, 
            Point[#2]}& , {
           FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`ptstyle$33207, 
            ReplaceAll[
            FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`funl$33207, \
$CellContext`t -> 
             FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`k$$]}]]], 
        PlotRange -> 
        FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`plotrange$33207],
       "Specifications" :> {{{
         FunctionRepository`$347ff35e8dc54e2f8812df1a0d3db14c`k$$, 0, 
          "Parameter"}, 0, 1.*^-9, 1.*^-12}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{406., {146.634033203125, 152.365966796875}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.900066132747693*^9, 3.900066134617852*^9}, {
   3.90006725417771*^9, 3.9000672690936317`*^9}, {3.900067399933316*^9, 
   3.9000674158626833`*^9}, 3.9000676327129564`*^9, {3.900067874293217*^9, 
   3.9000678757688055`*^9}, {3.900077130321578*^9, 3.900077144160981*^9}, 
   3.900078358260471*^9, 3.9000815395562983`*^9, {3.9000819134117107`*^9, 
   3.9000819476940575`*^9}, {3.9001489528076725`*^9, 3.900148958989328*^9}, 
   3.9001495334899845`*^9, {3.9001647995524883`*^9, 3.900164844407695*^9}},
 Background->GrayLevel[0.85],
 CellLabel->
  "Out[397]=",ExpressionUUID->"8d241e1c-6fba-4792-a536-050e708d7d3e"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1909., 1012.5},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellContext->Notebook,
SpellingDictionaries->{"CorrectWords"->{"Horbatsch"}},
Magnification:>1. Inherited,
FrontEndVersion->"13.2 for Microsoft Windows (64-bit) (January 30, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"742ef138-de8b-4668-b19d-6e9cfe2710a1"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 901, 15, 119, "Text",ExpressionUUID->"2eeb7966-7325-4277-82ec-f07e61611c61"],
Cell[CellGroupData[{
Cell[1484, 39, 190, 3, 71, "Section",ExpressionUUID->"6f565e33-5adc-44d5-803b-4ad0513aada9"],
Cell[1677, 44, 1121, 19, 64, "Input",ExpressionUUID->"6a4c7154-a70f-437d-80a3-9c67b2576039"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2835, 68, 193, 3, 71, "Section",ExpressionUUID->"f72f3a1d-79af-4971-a123-483d5eac55c8"],
Cell[3031, 73, 4669, 143, 292, "Input",ExpressionUUID->"af1cb04f-d80b-4735-b1fd-688a1a44cd7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7737, 221, 250, 4, 71, "Section",ExpressionUUID->"ca0149b0-55db-4ca7-9825-795dbcc37b31"],
Cell[CellGroupData[{
Cell[8012, 229, 18339, 467, 999, "Input",ExpressionUUID->"ec8051a9-b286-4672-82db-371c45c552fb"],
Cell[26354, 698, 5830, 133, 209, "Output",ExpressionUUID->"c2cf7e42-226d-4534-93a5-6a8a0caace9a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32233, 837, 206, 3, 71, "Section",ExpressionUUID->"48efb0eb-5b55-4cc7-9dea-c52ef8164cce"],
Cell[CellGroupData[{
Cell[32464, 844, 5385, 146, 415, "Input",ExpressionUUID->"fb2cccf3-9b56-44e0-beb5-8dbda99d728e"],
Cell[37852, 992, 7654, 163, 225, "Output",ExpressionUUID->"75367643-d838-444f-bd0b-42faae7b97f3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45555, 1161, 212, 3, 71, "Section",ExpressionUUID->"94b7af9b-ca98-47d3-993e-1b729998020d"],
Cell[CellGroupData[{
Cell[45792, 1168, 13096, 367, 774, "Input",ExpressionUUID->"3475e8e0-19ed-4166-baac-b0642f35da3e"],
Cell[58891, 1537, 16932, 354, 235, "Output",ExpressionUUID->"bc9974b1-9855-42f9-bbb3-51c93cc506a6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75872, 1897, 214, 3, 71, "Section",ExpressionUUID->"8be239ca-3735-4d41-9b65-d4ab685734a1"],
Cell[CellGroupData[{
Cell[76111, 1904, 11716, 312, 683, "Input",ExpressionUUID->"ec8d2b3c-31fe-48a2-87ba-66e714a12276"],
Cell[87830, 2218, 15141, 338, 213, "Output",ExpressionUUID->"c3ce60ba-0f15-477a-bb0c-cce2817bcb2c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[103020, 2562, 257, 4, 71, "Section",ExpressionUUID->"197ad755-1ac2-45c7-b9c8-68cab04ffb4a"],
Cell[CellGroupData[{
Cell[103302, 2570, 11227, 320, 818, "Input",ExpressionUUID->"888551a4-593b-44ca-bebe-ea960d7018d3"],
Cell[114532, 2892, 18430, 391, 229, "Output",ExpressionUUID->"9eb1d5b2-4a5f-4434-bc94-2a3e296a413e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[133011, 3289, 219, 3, 71, "Section",ExpressionUUID->"7d991649-df99-4fc9-bad4-c1855df192ee"],
Cell[CellGroupData[{
Cell[133255, 3296, 15118, 420, 876, "Input",ExpressionUUID->"d147ff30-e167-4e1e-9eb7-8ed80910a617"],
Cell[148376, 3718, 21333, 489, 578, "Output",ExpressionUUID->"7f10081a-ce42-4010-9f2f-a1a6ca83d4f0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[169758, 4213, 398, 8, 71, "Section",ExpressionUUID->"58305274-f6ea-4048-ac56-0e2e08a531d7"],
Cell[CellGroupData[{
Cell[170181, 4225, 20780, 564, 1723, "Input",ExpressionUUID->"56008cac-2b24-4623-a857-93d4deddd90d"],
Cell[190964, 4791, 37129, 809, 415, "Output",ExpressionUUID->"d6b8c612-18a2-4dcf-bdeb-7ed88abec87e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[228142, 5606, 338, 6, 67, "Section",ExpressionUUID->"ef6a2437-4488-4d6d-840b-60af19a1a84f"],
Cell[CellGroupData[{
Cell[228505, 5616, 5322, 155, 440, "Input",ExpressionUUID->"58387c4c-1456-4613-a4aa-53e256abbe93"],
Cell[233830, 5773, 2886, 58, 334, "Output",ExpressionUUID->"8d241e1c-6fba-4792-a536-050e708d7d3e"]
}, Open  ]]
}, Open  ]]
}
]
*)

